@@ -1,8 +1,8 @@
 /* prepdoc.c
  * Document Preparation System
  * Roger Sayle, Version 1.1, January 1994
- * Version 1.2
- * Herbert J. Bernstein, June 1999
+ * Version 1.3
+ * Herbert J. Bernstein, June 1999, rev Feb 2005
  */
 
 /* #define APPLEMAC */
@@ -451,7 +451,8 @@ static void ProcessCommand()
 
     ptr = Buffer+2;
     switch( Buffer[1] )
-    {   case('R'):  if( TextCol )
+    {   /* mR: Raw format text -- formatting in the text stream */
+	    case('R'):  if( TextCol )
                         putc('\n',OutFile);
                     if( SplitFlag )
                     {   SplitRawHTML(ptr);
@@ -459,7 +460,8 @@ static void ProcessCommand()
                     TextFlag = True;
                     TextCol = 0;
                     break;
-
+					
+        /* mT: Plain text */
         case('T'):  if( Format == RTFForm )
                     {   fprintf(OutFile,"%s {}\n",ptr);
                         TextCol = 0;
@@ -476,7 +478,45 @@ static void ProcessCommand()
                     } else DisplayText(ptr);
                     TextFlag = True;
                     break;
+					
+					
+		/* mQ:  Fixed font text (equivalent to HTML <tt>) */			
+		case('Q'):   if( Format == RTFForm )
+                    {   fprintf(OutFile,"\\pard{\\f2 \\fs20");
+						while (*ptr) {
+						  if (*ptr == ' ') {
+                                                    putc('\\',OutFile);
+                                                    putc('~',OutFile);
+                                                    ptr++;
+                                                  } else {
+						    putc(*ptr++,OutFile);
+                                                  }
+						}
+						fprintf(OutFile,"\\par}\n");
+                        TextCol = 0;
+                    } else if( Format == HTMLForm )
+                    {   fprintf(OutFile, "<tt>");
+					    while( *ptr ) {
+						    if (*ptr == ' ') {
+							  fprintf(OutFile, "&nbsp;");
+							  ptr++;
+							} else {
+                              FilterHTMLChar(&ptr);
+							}
+						}
+					    fprintf(OutFile, "</tt><br/>");
+                        putc('\n',OutFile);
+                        TextCol = 0;
+                    } else if( (Format!=TextForm) &&
+                               (Format!=HelpForm) &&
+                               (Format!=VaxForm) )
+                    {   fprintf(OutFile,"%s\n",ptr);
+                        TextCol = 0;
+                    } else DisplayText(ptr);
+                    TextFlag = True;
+                    break;
 
+        /* mP: Paragraph break */
         case('P'):  if( TextFlag )
                     {   if( Format == HTMLForm )
                         {   fputs("<p>\n",OutFile);
@@ -491,7 +531,8 @@ static void ProcessCommand()
                         TextCol = 0;
                     }
                     break;
-
+					
+        /* mB: Section break */
         case('B'):  if( TextFlag )
                     {   if( Format==HTMLForm )
                         {   if( !SplitFlag )
@@ -526,7 +567,8 @@ static void ProcessCommand()
                         TextCol = 0;
                     }
                     break;
-
+					
+		/* mS: Section heading */
         case('S'):  if( Format==TextForm )
                     {   len = strlen(ptr);
                         fprintf(OutFile,"%s\n",ptr);
@@ -561,7 +603,7 @@ static void ProcessCommand()
 
                     TextCol = 0;
                     break;
-
+        /* mX: Section reference (needs a tag) */
         case('X'):  while( *ptr!=' ' )
                         ptr++;
                     *ptr++ = 0;
@@ -598,6 +640,7 @@ static void ProcessCommand()
                     }
                     if (echar) Buffer[nblen-1] = echar;
                     
+	    /* mC: a citation (bolds the text except possibly for a terminal ".", ";", ",' or ":") */
         case('C'):  echar = Buffer[nblen-1];
                     if (echar == '.' || echar == ';' || echar == ',' || echar == ':') 
                     {    Buffer[nblen-1] = 0;
@@ -687,6 +730,8 @@ static void ProcessCommand()
                     TextFlag = True;
                     break;
                     
+		/* mK:  Caption text (Bolds the text, except possibly for a terminal ".", ";", "," or ":") 
+		        Similar to mC, but used with mP before and after for captions */  
         case('K'):  echar = Buffer[nblen-1];
                     if (echar == '.' || echar == ';' || echar == ',' || echar == ':') 
                     {    Buffer[nblen-1] = 0;
