@@ -1,10 +1,9 @@
-
 /***************************************************************************
- *                               RasMol 2.7.3                              *
+ *                              RasMol 2.7.5                               *
  *                                                                         *
  *                                 RasMol                                  *
  *                 Molecular Graphics Visualisation Tool                   *
- *                             6 February 2005                             *
+ *                              13 June 2009                               *
  *                                                                         *
  *                   Based on RasMol 2.6 by Roger Sayle                    *
  * Biomolecular Structures Group, Glaxo Wellcome Research & Development,   *
@@ -21,33 +20,57 @@
  *Philippe Valadon   RasTop 1.3     Aug 00     (C) Philippe Valadon 2000   *
  *                                                                         *
  *Herbert J.         RasMol 2.7.0   Mar 99     (C) Herbert J. Bernstein    * 
- *Bernstein          RasMol 2.7.1   Jun 99         1998-2001               *
+ *Bernstein          RasMol 2.7.1   Jun 99         1998-2008               *
  *                   RasMol 2.7.1.1 Jan 01                                 *
  *                   RasMol 2.7.2   Aug 00                                 *
  *                   RasMol 2.7.2.1 Apr 01                                 *
  *                   RasMol 2.7.2.1.1 Jan 04                               *
  *                   RasMol 2.7.3   Feb 05                                 *
+ *                   RasMol 2.7.3.1 Apr 06                                 *
+ *                   RasMol 2.7.4   Nov 07                                 *
+ *                   RasMol 2.7.4.1 Jan 08                                 *
+ *                   RasMol 2.7.4.2 Mar 08                                 *
+ *                   RasMol 2.7.5   May 09                                 *
  *                                                                         *
- *with RasMol 2.7.3 incorporating changes by Clarice Chigbo, Ricky Chachra,*
- *and Mamoru Yamanishi.  Work on RasMol 2.7.3 supported in part by         *
- *grants DBI-0203064, DBI-0315281 and EF-0312612 from the U.S. National    *
- *Science Foundation and grant DE-FG02-03ER63601 from the U.S. Department  *
- *of Energy.                                                               *
+ * RasMol 2.7.5 incorporates changes by T. Ikonen, G. McQuillan, N. Darakev*
+ * and L. Andrews (via the neartree package).  Work on RasMol 2.7.5        *
+ * supported in part by grant 1R15GM078077-01 from the National Institute  *
+ * of General Medical Sciences (NIGMS), U.S. National Institutes of Health *
+ * and by grant ER63601-1021466-0009501 from the Office of Biological &    *
+ * Environmental Research (BER), Office of Science, U. S. Department of    *
+ * Energy.  RasMol 2.7.4 incorporated  changes by G. Todorov, Nan Jia,     *
+ * N. Darakev, P. Kamburov, G. McQuillan, and J. Jemilawon. Work on RasMol *
+ * 2.7.4 supported in part by grant 1R15GM078077-01 from the NIGMS/NIH and *
+ * grant ER63601-1021466-0009501 from BER/DOE.  RasMol 2.7.3 incorporates  *
+ * changes by Clarice Chigbo, Ricky Chachra, and Mamoru Yamanishi.  Work   *
+ * on RasMol 2.7.3 supported in part by grants DBI-0203064, DBI-0315281    *
+ * and EF-0312612 from the U.S. National Science Foundation and grant      *
+ * DE-FG02-03ER63601 from BER/DOE. The content is solely the responsibility*
+ * of the authors and does not necessarily represent the official views of *
+ * the funding organizations.                                              *
+ *                                                                         *
+ * The code for use of RasMol under GTK in RasMol 2.7.4.2 and 2.7.5 was    *
+ * written by Teemu Ikonen.                                                *
  *                                                                         *
  *                    and Incorporating Translations by                    *
- *  Author                               Item                      Language*
+ *  Author                               Item                     Language *
  *  Isabel Servan Martinez,                                                *
- *  Jose Miguel Fernandez Fernandez      2.6   Manual              Spanish *
- *  Jose Miguel Fernandez Fernandez      2.7.1 Manual              Spanish *
- *  Fernando Gabriel Ranea               2.7.1 menus and messages  Spanish *
- *  Jean-Pierre Demailly                 2.7.1 menus and messages  French  *
+ *  Jose Miguel Fernandez Fernandez      2.6   Manual             Spanish  *
+ *  Jose Miguel Fernandez Fernandez      2.7.1 Manual             Spanish  *
+ *  Fernando Gabriel Ranea               2.7.1 menus and messages Spanish  *
+ *  Jean-Pierre Demailly                 2.7.1 menus and messages French   *
  *  Giuseppe Martini, Giovanni Paolella, 2.7.1 menus and messages          *
- *  A. Davassi, M. Masullo, C. Liotto    2.7.1 help file           Italian *
+ *  A. Davassi, M. Masullo, C. Liotto    2.7.1 help file          Italian  *
+ *  G. Pozhvanov                         2.7.3 menus and messages Russian  *
+ *  G. Todorov                           2.7.3 menus and messages Bulgarian*
+ *  Nan Jia, G. Todorov                  2.7.3 menus and messages Chinese  *
+ *  Mamoru Yamanishi, Katajima Hajime    2.7.3 menus and messages Japanese *
+ *                                                                         *
  *                                                                         *
  *                             This Release by                             *
- * Herbert J. Bernstein, Bernstein + Sons, P.O. Box 177, Bellport, NY, USA *
+ * Herbert J. Bernstein, Bernstein + Sons, 5 Brewster Ln, Bellport, NY, USA*
  *                       yaya@bernstein-plus-sons.com                      *
- *               Copyright(C) Herbert J. Bernstein 1998-2005               *
+ *               Copyright(C) Herbert J. Bernstein 1998-2008               *
  *                                                                         *
  *                READ THE FILE NOTICE FOR RASMOL LICENSES                 *
  *Please read the file NOTICE for important notices which apply to this    *
@@ -254,6 +277,87 @@ extern "C" {
 
 #include "rasmol.h"
 
+#ifdef USE_CBFLIB
+#include <stdio.h>
+#include "cmndline.h"
+#include "cif.h"
+#include <string.h>
+#include <stdlib.h>
+#include <errno.h>
+#include <unistd.h>
+#define C2CBUFSIZ 4096
+
+#if defined(IBMPC) || defined(VMS) || defined(APPLEMAC)
+#define NOMKSTEMP
+#endif
+    
+    int cif_read_file (cbf_handle handle, FILE *stream) {
+        char *ciftmp=NULL;
+        int nbytes;
+        FILE *file;
+#ifndef NOMKSTEMP
+        int ciftmpfd;
+#endif
+        char buffer [4096];
+        
+        ciftmp = (char *)_fmalloc(strlen("/tmp/rsml275XXXXXX")+1);
+        strcpy(ciftmp, "/tmp/rsml275XXXXXX");
+#ifdef NOMKSTEMP
+        if ((file = tmpfile()) == NULL )
+        {       WriteString("Can't create temporary file \n");
+                sprintf(buffer,"%s\n",strerror(errno));
+                WriteString(buffer);
+                RasMolExit();
+        }
+        _ffree(ciftmp);
+#else
+        if ((ciftmpfd = mkstemp(ciftmp)) == -1 || (file = fdopen(ciftmpfd, "wb+")) == NULL) {
+            strcpy(ciftmp, "rsml275XXXXXX");
+            if ((ciftmpfd = mkstemp(ciftmp)) == -1 || (file = fdopen(ciftmpfd, "wb+")) == NULL) {        
+                sprintf(buffer,"\n rasmol: Can't create temporary file %s.\n", ciftmp);
+                WriteString(buffer);
+                sprintf(buffer,"%s\n",strerror(errno));
+                WriteString(buffer);
+                RasMolExit();
+            }
+        }
+        unlink(ciftmp);
+        _ffree(ciftmp);
+#endif
+        if (Recycle) {
+            nbytes = strlen(Recycle);
+            if(nbytes != fwrite(Recycle, 1, nbytes, file)) {
+                sprintf(buffer,"Failed to write %s.\n", ciftmp);
+                WriteString(buffer);
+                RasMolExit();
+            }
+            nbytes=1;
+            if(nbytes != fwrite("\n", 1, nbytes, file)) {
+                sprintf(buffer,"Failed to write %s.\n", ciftmp);
+                WriteString(buffer);
+                RasMolExit();
+            }
+        }
+        if (stream)
+        while ((nbytes = fread(buffer, 1, C2CBUFSIZ, stream))) {
+            if(nbytes != fwrite(buffer, 1, nbytes, file)) {
+                sprintf(buffer,"Failed to write %s.\n", ciftmp);
+                WriteString(buffer);
+                RasMolExit();
+            }
+        }
+        
+        rewind(file);
+        cbf_failnez(cbf_read_widefile(handle,file, MSG_DIGEST));
+        
+        return 0;
+    }
+
+
+
+#else
+
+
 #ifdef IBMPC
 #include <windows.h>
 #include <malloc.h>
@@ -1474,7 +1578,7 @@ int cif_get_character (cif_file __far *file)
           file->last_read = '\n';
         }
       } else {
-        file->last_read = getc (file->stream);
+        file->last_read = fgetc (file->stream);
         ++(file->fpos);
         if (file->fpos > file->fend) file->fend = file->fpos;
       }
@@ -1531,6 +1635,58 @@ int cif_return_text (int code, YYSTYPE __far *val, int offset,
 }
 
 
+  /* Get the name of the current data block */
+int cif_datablock_name (cif_handle handle, char __far * __far * datablockname)
+{
+  cif_node *node;
+
+  if (!handle)
+
+    return CIF_ARGUMENT;
+
+
+    /* Find the data block node */
+
+  cif_failnez (cif_find_parent (&node, handle->node, CIF_DATABLOCK))
+
+
+    /* Get the name */
+
+  return cif_get_name (datablockname, node);
+}
+
+
+
+
+
+  /* Make the first data block the current data block */
+
+int cif_rewind_datablock (cif_handle handle)
+{
+  cif_node *node;
+
+  if (!handle)
+    return CIF_ARGUMENT;
+
+
+    /* Find the root node */
+
+  cif_failnez (cif_find_parent (&node, handle->node, CIF_ROOT))
+
+
+    /* Find the first child */
+
+  cif_failnez (cif_get_child (&node, node, 0))
+  handle->node = node;
+
+
+    /* Success */
+
+  return 0;
+}
+
+
+
   /* Get the next token */
 
 int cif_lex (YYSTYPE __far *val, cif_file __far *file)
@@ -2136,7 +2292,7 @@ int cif_count_columns (cif_handle handle, unsigned int __far *columns)
 
   return cif_count_children (columns, node);
 }
-
+#endif
 
 
 #ifdef __cplusplus
