@@ -1,9 +1,9 @@
 /***************************************************************************
- *                            RasMol 2.7.2.1.1                             *
+ *                              RasMol 2.7.5                               *
  *                                                                         *
  *                                 RasMol                                  *
  *                 Molecular Graphics Visualisation Tool                   *
- *                            26 January 2004                              *
+ *                              13 June 2009                               *
  *                                                                         *
  *                   Based on RasMol 2.6 by Roger Sayle                    *
  * Biomolecular Structures Group, Glaxo Wellcome Research & Development,   *
@@ -20,54 +20,61 @@
  *Philippe Valadon   RasTop 1.3     Aug 00     (C) Philippe Valadon 2000   *
  *                                                                         *
  *Herbert J.         RasMol 2.7.0   Mar 99     (C) Herbert J. Bernstein    * 
- *Bernstein          RasMol 2.7.1   Jun 99         1998-2001               *
+ *Bernstein          RasMol 2.7.1   Jun 99         1998-2008               *
  *                   RasMol 2.7.1.1 Jan 01                                 *
  *                   RasMol 2.7.2   Aug 00                                 *
  *                   RasMol 2.7.2.1 Apr 01                                 *
  *                   RasMol 2.7.2.1.1 Jan 04                               *
+ *                   RasMol 2.7.3   Feb 05                                 *
+ *                   RasMol 2.7.3.1 Apr 06                                 *
+ *                   RasMol 2.7.4   Nov 07                                 *
+ *                   RasMol 2.7.4.1 Jan 08                                 *
+ *                   RasMol 2.7.4.2 Mar 08                                 *
+ *                   RasMol 2.7.5   May 09                                 *
+ *                                                                         *
+ * RasMol 2.7.5 incorporates changes by T. Ikonen, G. McQuillan, N. Darakev*
+ * and L. Andrews (via the neartree package).  Work on RasMol 2.7.5        *
+ * supported in part by grant 1R15GM078077-01 from the National Institute  *
+ * of General Medical Sciences (NIGMS), U.S. National Institutes of Health *
+ * and by grant ER63601-1021466-0009501 from the Office of Biological &    *
+ * Environmental Research (BER), Office of Science, U. S. Department of    *
+ * Energy.  RasMol 2.7.4 incorporated  changes by G. Todorov, Nan Jia,     *
+ * N. Darakev, P. Kamburov, G. McQuillan, and J. Jemilawon. Work on RasMol *
+ * 2.7.4 supported in part by grant 1R15GM078077-01 from the NIGMS/NIH and *
+ * grant ER63601-1021466-0009501 from BER/DOE.  RasMol 2.7.3 incorporates  *
+ * changes by Clarice Chigbo, Ricky Chachra, and Mamoru Yamanishi.  Work   *
+ * on RasMol 2.7.3 supported in part by grants DBI-0203064, DBI-0315281    *
+ * and EF-0312612 from the U.S. National Science Foundation and grant      *
+ * DE-FG02-03ER63601 from BER/DOE. The content is solely the responsibility*
+ * of the authors and does not necessarily represent the official views of *
+ * the funding organizations.                                              *
+ *                                                                         *
+ * The code for use of RasMol under GTK in RasMol 2.7.4.2 and 2.7.5 was    *
+ * written by Teemu Ikonen.                                                *
  *                                                                         *
  *                    and Incorporating Translations by                    *
- *  Author                               Item                      Language*
- *  Isabel Servn Martnez,                                                *
- *  Jos Miguel Fernndez Fernndez      2.6   Manual              Spanish *
- *  Jos Miguel Fernndez Fernndez      2.7.1 Manual              Spanish *
- *  Fernando Gabriel Ranea               2.7.1 menus and messages  Spanish *
- *  Jean-Pierre Demailly                 2.7.1 menus and messages  French  *
+ *  Author                               Item                     Language *
+ *  Isabel Servan Martinez,                                                *
+ *  Jose Miguel Fernandez Fernandez      2.6   Manual             Spanish  *
+ *  Jose Miguel Fernandez Fernandez      2.7.1 Manual             Spanish  *
+ *  Fernando Gabriel Ranea               2.7.1 menus and messages Spanish  *
+ *  Jean-Pierre Demailly                 2.7.1 menus and messages French   *
  *  Giuseppe Martini, Giovanni Paolella, 2.7.1 menus and messages          *
- *  A. Davassi, M. Masullo, C. Liotto    2.7.1 help file           Italian *
+ *  A. Davassi, M. Masullo, C. Liotto    2.7.1 help file          Italian  *
+ *  G. Pozhvanov                         2.7.3 menus and messages Russian  *
+ *  G. Todorov                           2.7.3 menus and messages Bulgarian*
+ *  Nan Jia, G. Todorov                  2.7.3 menus and messages Chinese  *
+ *  Mamoru Yamanishi, Katajima Hajime    2.7.3 menus and messages Japanese *
  *                                                                         *
  *                             This Release by                             *
- * Herbert J. Bernstein, Bernstein + Sons, P.O. Box 177, Bellport, NY, USA *
+ * Herbert J. Bernstein, Bernstein + Sons, 5 Brewster Ln, Bellport, NY, USA*
  *                       yaya@bernstein-plus-sons.com                      *
- *               Copyright(C) Herbert J. Bernstein 1998-2001               *
+ *               Copyright(C) Herbert J. Bernstein 1998-2008               *
  *                                                                         *
- * Please read the file NOTICE for important notices which apply to this   *
- * package. If you are not going to make changes to RasMol, you are not    *
- * only permitted to freely make copies and distribute them, you are       *
- * encouraged to do so, provided you do the following:                     *
- *   * 1. Either include the complete documentation, especially the file   *
- *     NOTICE, with what you distribute or provide a clear indication      *
- *     where people can get a copy of the documentation; and               *
- *   * 2. Please give credit where credit is due citing the version and    *
- *     original authors properly; and                                      *
- *   * 3. Please do not give anyone the impression that the original       *
- *     authors are providing a warranty of any kind.                       *
- *                                                                         *
- * If you would like to use major pieces of RasMol in some other program,  *
- * make modifications to RasMol, or in some other way make what a lawyer   *
- * would call a "derived work", you are not only permitted to do so, you   *
- * are encouraged to do so. In addition to the things we discussed above,  *
- * please do the following:                                                *
- *   * 4. Please explain in your documentation how what you did differs    *
- *     from this version of RasMol; and                                    *
- *   * 5. Please make your modified source code available.                 *
- *                                                                         *
- * This version of RasMol is not in the public domain, but it is given     *
- * freely to the community in the hopes of advancing science. If you make  *
- * changes, please make them in a responsible manner, and please offer us  *
- * the opportunity to include those changes in future versions of RasMol.  *
+ *                READ THE FILE NOTICE FOR RASMOL LICENSES                 *
+ *Please read the file NOTICE for important notices which apply to this    *
+ *package and for license terms (GPL or RASLIC).                           *
  ***************************************************************************/
-
 /**********************************************************************
  *  cif_ctonum.c                                                      *
  *                                                                    *
@@ -188,7 +195,10 @@
 extern "C" {
 #endif
 
+#ifndef _USE_RASMOL_H_
 #define _USE_RASMOL_H_
+#endif
+
 #ifdef _USE_RASMOL_H_
 #include "rasmol.h"
 #else
