@@ -1,10 +1,10 @@
-
 /***************************************************************************
- *                               RasMol 2.7.3                              *
+ *                             RasMol 2.7.5                                *
  *                                                                         *
  *                                 RasMol                                  *
  *                 Molecular Graphics Visualisation Tool                   *
- *                             6 February 2005                             *
+ *                              13 June 2009                               *
+ *                          (rev. 9 August 2009)                           *
  *                                                                         *
  *                   Based on RasMol 2.6 by Roger Sayle                    *
  * Biomolecular Structures Group, Glaxo Wellcome Research & Development,   *
@@ -21,33 +21,56 @@
  *Philippe Valadon   RasTop 1.3     Aug 00     (C) Philippe Valadon 2000   *
  *                                                                         *
  *Herbert J.         RasMol 2.7.0   Mar 99     (C) Herbert J. Bernstein    * 
- *Bernstein          RasMol 2.7.1   Jun 99         1998-2001               *
+ *Bernstein          RasMol 2.7.1   Jun 99         1998-2008               *
  *                   RasMol 2.7.1.1 Jan 01                                 *
  *                   RasMol 2.7.2   Aug 00                                 *
  *                   RasMol 2.7.2.1 Apr 01                                 *
  *                   RasMol 2.7.2.1.1 Jan 04                               *
  *                   RasMol 2.7.3   Feb 05                                 *
+ *                   RasMol 2.7.3.1 Apr 06                                 *
+ *                   RasMol 2.7.4   Nov 07                                 *
+ *                   RasMol 2.7.4.1 Jan 08                                 *
+ *                   RasMol 2.7.4.2 Mar 08                                 *
+ *                   RasMol 2.7.5   May 09                                 *
  *                                                                         *
- *with RasMol 2.7.3 incorporating changes by Clarice Chigbo, Ricky Chachra,*
- *and Mamoru Yamanishi.  Work on RasMol 2.7.3 supported in part by         *
- *grants DBI-0203064, DBI-0315281 and EF-0312612 from the U.S. National    *
- *Science Foundation and grant DE-FG02-03ER63601 from the U.S. Department  *
- *of Energy.                                                               *
+ * RasMol 2.7.5 incorporates changes by T. Ikonen, G. McQuillan, N. Darakev*
+ * and L. Andrews (via the neartree package).  Work on RasMol 2.7.5        *
+ * supported in part by grant 1R15GM078077-01 from the National Institute  *
+ * of General Medical Sciences (NIGMS), U.S. National Institutes of Health *
+ * and by grant ER63601-1021466-0009501 from the Office of Biological &    *
+ * Environmental Research (BER), Office of Science, U. S. Department of    *
+ * Energy.  RasMol 2.7.4 incorporated  changes by G. Todorov, Nan Jia,     *
+ * N. Darakev, P. Kamburov, G. McQuillan, and J. Jemilawon. Work on RasMol *
+ * 2.7.4 supported in part by grant 1R15GM078077-01 from the NIGMS/NIH and *
+ * grant ER63601-1021466-0009501 from BER/DOE.  RasMol 2.7.3 incorporates  *
+ * changes by Clarice Chigbo, Ricky Chachra, and Mamoru Yamanishi.  Work   *
+ * on RasMol 2.7.3 supported in part by grants DBI-0203064, DBI-0315281    *
+ * and EF-0312612 from the U.S. National Science Foundation and grant      *
+ * DE-FG02-03ER63601 from BER/DOE. The content is solely the responsibility*
+ * of the authors and does not necessarily represent the official views of *
+ * the funding organizations.                                              *
+ *                                                                         *
+ * The code for use of RasMol under GTK in RasMol 2.7.4.2 and 2.7.5 was    *
+ * written by Teemu Ikonen.                                                *
  *                                                                         *
  *                    and Incorporating Translations by                    *
- *  Author                               Item                      Language*
+ *  Author                               Item                     Language *
  *  Isabel Servan Martinez,                                                *
- *  Jose Miguel Fernandez Fernandez      2.6   Manual              Spanish *
- *  Jose Miguel Fernandez Fernandez      2.7.1 Manual              Spanish *
- *  Fernando Gabriel Ranea               2.7.1 menus and messages  Spanish *
- *  Jean-Pierre Demailly                 2.7.1 menus and messages  French  *
+ *  Jose Miguel Fernandez Fernandez      2.6   Manual             Spanish  *
+ *  Jose Miguel Fernandez Fernandez      2.7.1 Manual             Spanish  *
+ *  Fernando Gabriel Ranea               2.7.1 menus and messages Spanish  *
+ *  Jean-Pierre Demailly                 2.7.1 menus and messages French   *
  *  Giuseppe Martini, Giovanni Paolella, 2.7.1 menus and messages          *
- *  A. Davassi, M. Masullo, C. Liotto    2.7.1 help file           Italian *
+ *  A. Davassi, M. Masullo, C. Liotto    2.7.1 help file          Italian  *
+ *  G. Pozhvanov                         2.7.3 menus and messages Russian  *
+ *  G. Todorov                           2.7.3 menus and messages Bulgarian*
+ *  Nan Jia, G. Todorov                  2.7.3 menus and messages Chinese  *
+ *  Mamoru Yamanishi, Katajima Hajime    2.7.3 menus and messages Japanese *
  *                                                                         *
  *                             This Release by                             *
- * Herbert J. Bernstein, Bernstein + Sons, P.O. Box 177, Bellport, NY, USA *
+ * Herbert J. Bernstein, Bernstein + Sons, 5 Brewster Ln, Bellport, NY, USA*
  *                       yaya@bernstein-plus-sons.com                      *
- *               Copyright(C) Herbert J. Bernstein 1998-2005               *
+ *               Copyright(C) Herbert J. Bernstein 1998-2008               *
  *                                                                         *
  *                READ THE FILE NOTICE FOR RASMOL LICENSES                 *
  *Please read the file NOTICE for important notices which apply to this    *
@@ -489,6 +512,14 @@ void InvalidateCmndLine( void )
     CommandActive=False;
 }
 
+void InterruptCommands (char __huge * message)
+{
+    InvalidateCmndLine();
+    WriteString(message);
+    WriteChar('\n');
+    ResetCommandLine(0);
+}
+
 
 static void ClampDial( int dial, Real value )
 {
@@ -611,9 +642,10 @@ void SetMouseMode( int mode )
     
     switch( mode )
     {   case(MMRasMol):  MouseBinding = MouseRasMol;  MouseMode = MMRasMol;    break;
+        case(MMRasOld):  MouseBinding = MouseRasMol;  MouseMode = MMRasOld;    break;
         case(MMInsight): MouseBinding = MouseInsight; MouseMode = MMInsight;   break;
-        case(MMQuanta):  MouseBinding = MouseQuanta;  MouseMode = MMQuanta; break;
-        case(MMSybyl):   MouseBinding = MouseSybyl;   MouseMode = MMSybyl;  break;
+        case(MMQuanta):  MouseBinding = MouseQuanta;  MouseMode = MMQuanta;    break;
+        case(MMSybyl):   MouseBinding = MouseSybyl;   MouseMode = MMSybyl;     break;
     }
 
     /* Should also test for BindingActive(MMSft|MMCtl)! */
@@ -621,92 +653,243 @@ void SetMouseMode( int mode )
     SetMouseUpdateStatus(stat);            
 }
 
+/*
+   PerformMouseFunc
+     func:  MM_ROTX -- a change in the Y-direction for the purpose
+                       of rotating around the X-axis
+            MM_ROTY -- a change in the X-direction for the purpose
+                       of rotating aount the Y-axis
+ 
+     The mouse rasmol old interpretation is based on breaking
+     the screen into zones, by eigths of the width and height.
+     In the outer eighth in each direction, the rotations
+     are actualy around the Z-axis.  In the middle 2-eights
+     the rotations ar entirely around the X-axis for
+     Y displacements, and entirely around the Y-axis for
+     X dosplacements.  Between these two zones the two rotation
+     modes are mixed
+   
+ 
+ 
+       (0,0)                                        (XRange,0)
+         ------------------------------------------------
+        |     |     |     |     |     |     |     |     |
+        |  Z  |  Z  |  Z  |  Z  |  Z  |  Z  |  Z  |  Z  |
+        |     |     |     |     |     |     |     |     |
+         ------------------------------------------------
+        |     |     |     |     |     |     |     |     |
+        |  Z  |     |     |     |     |     |     |  Z  |
+        |     |     |     |     |     |     |     |     |
+         ------------------------------------------------
+        |     |     |     |     |     |     |     |     |
+        |  Z  |     |     |     |     |     |     |  Z  |
+        |     |     |     |     |     |     |     |     |
+         ------------------------------------------------
+        |     |     |     |     |     |     |     |     |
+        |  Z  |     |     |  XY | XY  |     |     |  Z  |
+        |     |     |     |     |     |     |     |     |
+         ------------------------------------------------
+        |     |     |     |     |     |     |     |     |
+        |  Z  |     |     |  XY | XY  |     |     |  Z  |
+        |     |     |     |     |     |     |     |     |
+         ------------------------------------------------
+        |     |     |     |     |     |     |     |     |
+        |  Z  |     |     |     |     |     |     |     |
+        |     |     |     |     |     |     |     |     |
+         ------------------------------------------------
+        |     |     |     |     |     |     |     |     |
+        |  Z  |     |     |     |     |     |     |     |
+        |     |     |     |     |     |     |     |     |
+         ------------------------------------------------
+        |     |     |     |     |     |     |     |     |
+        |  Z  |  Z  |  Z  |  Z  |  Z  |  Z  |  Z  |  Z  |
+        |     |     |     |     |     |     |     |     |
+         ------------------------------------------------
+    (0,YRange)                                         (Xrange,YRange)
+ 
+ This provides a approximation to track-ball behavior, where
+ twisting of the trackball creates a Z-rotation.  In this case,
+ the appropriate DialValues are incremented by the indicated
+ motion, to eventually be used against as base set of Euler
+ angles [LastDialValue[DialRX], LastDialValue[DialRY], LastDialValue[DialRZ]]
+ 
+ In the new mode, the screen is treated as a continuous trackball,
+ using any changes in [DialVaue[DialRX],DialValue[DialRY]] to infer
+ a rotation around an axis at right angles to the displacement.
+ The accumulated rotation is held in DialQRot.   The rotation is applied 
+ in transfor.c.
+ 
+ */
 
 static void PerformMouseFunc( int func, int delta, int max )
 {   Real xcomp, ycomp, zcomp;
+    Real dvalue, nvalue;
     int  dist;
+    CQRQuaternion lrot,trot;
+    CQRQuaternion q3;
     
     switch( func )
-    {   case(MM_ROTX):  if ( (RotMode == RotBond) && BondSelected) {
-                          WrapDial( DialBRot, (Real)(2*delta)/max );
-                        } else {
-                          dist = PointX-XRange/2;
-                          if (dist < -XRange/8) {
-                            dist += XRange/8;
-                            dist *= 2;
-                            if (dist < -XRange/2) dist=-XRange/2;
-                          } else {
-                            dist -= XRange/8;
-                            if (dist < 0 ) dist = 0;
-                            dist *=2;
-                            if (dist > XRange/2) dist = XRange/2;
-                          }
-                          xcomp = (Real)(delta*(XRange/2-AbsFun(dist)))/((Real)(XRange/2));
-                          zcomp = (Real)(delta*dist)/((Real)(XRange/2));
-                          WrapDial( DialRX, 2*xcomp/(Real)max );
-                          WrapDial( DialRZ, 2*zcomp/(Real)max );
-                         /* WrapDial( DialRX, (Real)(2*delta)/max ); */
-                        }
-                        ReDrawFlag |= RFRotateX|RFRotateZ;
-                        break;
-                        
-        case(MM_ROTY):  if ( (RotMode == RotBond) && BondSelected) {
-                          WrapDial( DialBRot, (Real)(2*delta)/max );
-                        } else {
-                          dist = PointY-YRange/2;
-                          if (dist < -YRange/8) {
-                            dist += YRange/8;
-                            dist *= 2;
-                            if (dist < -YRange/2) dist=-YRange/2;
-                          } else {
-                            dist -= YRange/8;
-                            if (dist < 0 ) dist = 0;
-                            dist *=2;
-                            if (dist > YRange/2) dist = YRange/2;
-                          }
-                          ycomp = (Real)(delta*(YRange/2-AbsFun(dist)))/((Real)(YRange/2));
+    {   case(MM_ROTX):  dvalue = ((Real)(2*delta))/((Real)(max));
+            if ( (RotMode == RotBond) && BondSelected) {
+                WrapDial( DialBRot, dvalue );
+                BondSelected->BRotValue = DialValue[DialBRot];
+                ReDrawFlag |= RFRotBond;
+            } else if (MouseMode==MMRasOld) {
+                dist = PointX-XRange/2;
+                if (dist < -XRange/8) {
+                    dist += XRange/8;
+                    dist *= 2;
+                    if (dist < -XRange/2) dist=-XRange/2;
+                } else {
+                    dist -= XRange/8;
+                    if (dist < 0 ) dist = 0;
+                    dist *=2;
+                    if (dist > XRange/2) dist = XRange/2;
+                }
+                xcomp = dvalue*(Real)((XRange/2-AbsFun(dist)))/((Real)(XRange/2));
+                zcomp = dvalue*(Real)(dist)/((Real)(XRange/2));
+                WrapDial( DialRX, xcomp );
+                WrapDial( DialRZ, zcomp);
+                ReDrawFlag |= RFRotateX|RFRotateZ;
+            } else if (MouseMode==MMRasMol) {
+                xcomp = ((Real)(2*PointX-XRange))/((Real)(XRange));
+                ycomp = ((Real)(2*PointY-YRange))/((Real)(YRange));
+                zcomp = xcomp*xcomp+ycomp*ycomp;
+                if (zcomp > 1.) {
+                    zcomp = 0.;
+                } else {
+                    zcomp = sqrt(1.-zcomp);
+                }
+                CQRMSet(q3,0.,zcomp,0,xcomp)
+                CQRMNormsq(nvalue,q3);
+                if (DialQRot.w==0. && DialQRot.x==0. && DialQRot.y==0 &&DialQRot.z==0) {
+                    if (nvalue==0.) {
+                        CQRMSet(DialQRot,cos(PI*dvalue/2.),0.,0.,sin(PI*dvalue/2.));
+                    } else {
+                        nvalue = sqrt(nvalue);
+                        CQRMSet(DialQRot,cos(PI*dvalue/2.),
+                                sin(PI*dvalue/2.)*q3.x/nvalue,
+                                sin(PI*dvalue/2.)*q3.y/nvalue,
+                                sin(PI*dvalue/2.)*q3.z/nvalue);
+                    }
+                } else {
+                    if (nvalue==0.) {
+                        CQRMSet(lrot,cos(PI*dvalue),0.,0.,sin(PI*dvalue));
+                    } else {
+                        nvalue = sqrt(nvalue);
+                        CQRMSet(lrot,cos(PI*dvalue/2.),
+                                sin(PI*dvalue/2.)*q3.x/nvalue,
+                                sin(PI*dvalue/2.)*q3.y/nvalue,
+                                sin(PI*dvalue/2.)*q3.z/nvalue);
+                    }
+                    CQRMMultiply(trot,lrot,DialQRot);
+                    CQRMCopy(DialQRot,trot);
+                }
+                ReDrawFlag |= RFRotateX|RFRotateY|RFRotateZ;
+            } else {
+                WrapDial( DialRX, (Real)(2*delta)/max );
+                ReDrawFlag |= RFRotateX;
+            }
+            break;
+            
+        case(MM_ROTY):
+            dvalue = ((Real)(2*delta))/((Real)(max));
+            if ( (RotMode == RotBond) && BondSelected) {
+                WrapDial( DialBRot, dvalue );
+                BondSelected->BRotValue = DialValue[DialBRot];
+                ReDrawFlag |= RFRotBond;
+            } else if (MouseMode==MMRasOld) {
+                dist = PointY-YRange/2;
+                if (dist < -YRange/8) {
+                    dist += YRange/8;
+                    dist *= 2;
+                    if (dist < -YRange/2) dist=-YRange/2;
+                } else {
+                    dist -= YRange/8;
+                    if (dist < 0 ) dist = 0;
+                    dist *=2;
+                    if (dist > YRange/2) dist = YRange/2;
+                }
+                ycomp = dvalue*(Real)((YRange/2-AbsFun(dist)))/((Real)(YRange/2));
 #ifdef INVERT
-                          zcomp = (Real)(delta*dist)/((Real)(YRange/2));
+                zcomp = dvalue*(Real)(dist)/((Real)(YRange/2));
 #else
-                          zcomp = (Real)(-delta*dist)/((Real)(YRange/2));
+                zcomp = dvalue*(Real)(-dist)/((Real)(YRange/2));
 #endif
-                          WrapDial( DialRY, 2*ycomp/(Real)max );
-                          WrapDial( DialRZ, 2*zcomp/(Real)max );
-                        /* WrapDial( DialRY, (Real)(2*delta)/max ); */
-                        }
-                        ReDrawFlag |= RFRotateY|RFRotateZ;
-                        break;
-                        
+                WrapDial( DialRY, ycomp );
+                WrapDial( DialRZ, zcomp );
+                ReDrawFlag |= RFRotateY|RFRotateZ;
+            } else if (MouseMode==MMRasMol) {
+                xcomp = ((Real)(2*PointX-XRange))/((Real)(XRange));
+                ycomp = ((Real)(2*PointY-YRange))/((Real)(YRange));
+                zcomp = xcomp*xcomp+ycomp*ycomp;
+                if (zcomp > 1.) {
+                    zcomp = 0.;
+                } else {
+                    zcomp = sqrt(1.-zcomp);
+                }
+                CQRMSet(q3,0.,0.,zcomp,-ycomp);
+                CQRMNormsq(nvalue,q3);
+                if (DialQRot.w==0. && DialQRot.x==0. && DialQRot.y==0 &&DialQRot.z==0) {
+                    if (nvalue==0.) {
+                        CQRMSet(DialQRot,cos(PI*dvalue),0.,0.,sin(PI*dvalue/2.));
+                    } else {
+                        nvalue = sqrt(nvalue);
+                        CQRMSet(DialQRot,cos(PI*dvalue/2.),
+                                sin(PI*dvalue/2.)*q3.x/nvalue,
+                                sin(PI*dvalue/2.)*q3.y/nvalue,
+                                sin(PI*dvalue/2.)*q3.z/nvalue);
+                    }
+                } else {
+                    if (nvalue==0.) {
+                        CQRMSet(lrot,cos(PI*dvalue/2.),0.,0.,sin(PI*dvalue/2.));
+                    } else {
+                        nvalue = sqrt(nvalue);
+                        CQRMSet(lrot,cos(PI*dvalue/2.),
+                                sin(PI*dvalue/2.)*q3.x/nvalue,
+                                sin(PI*dvalue/2.)*q3.y/nvalue,
+                                sin(PI*dvalue/2.)*q3.z/nvalue);
+                    }
+                    CQRMMultiply(trot,lrot,DialQRot);
+                    CQRMCopy(DialQRot,trot);
+                }
+                ReDrawFlag |= RFRotateX|RFRotateY|RFRotateZ;
+            }else {
+                WrapDial( DialRY, (Real)(2*delta)/max );
+                ReDrawFlag |= RFRotateY;
+            }
+            break;
+            
         case(MM_ROTZ):  WrapDial( DialRZ, (Real)(2*delta)/max );
-                        ReDrawFlag |= RFRotateZ;
-                        break;
-                        
+            ReDrawFlag |= RFRotateZ;
+            break;
+            
         case(MM_ZOOM):  ClampDial( DialZoom, (Real)(2*delta)/max );
-                        ReDrawFlag |= RFZoom;
-                        break;
-                        
+            ReDrawFlag |= RFZoom;
+            break;
+            
         case(MM_TRNX):  ClampDial( DialTX, (Real)delta/max );
-                        ReDrawFlag |= RFTransX|RFTransZ;
-                        break;
-
+            ReDrawFlag |= RFTransX|RFTransZ;
+            break;
+            
         case(MM_TRNY):  ClampDial( DialTY, (Real)delta/max );
-                        ReDrawFlag |= RFTransY|RFTransZ;
-                        break;
-
+            ReDrawFlag |= RFTransY|RFTransZ;
+            break;
+            
         case(MM_CLIP):  ClampDial( DialSlab, (Real)delta/max );
-                        ReDrawFlag |= RFSlab;
-                        UseSlabPlane = True;
-                        UseShadow = False;
-                        break;
-
+            ReDrawFlag |= RFSlab;
+            UseSlabPlane = True;
+            UseShadow = False;
+            break;
+            
         case(MM_DEPT):  ClampDial( DialBClip, (Real)delta/max );
-                        ReDrawFlag |= RFRotate;
-                        UseDepthPlane = True;
-                        break;
+            ReDrawFlag |= RFRotate;
+            UseDepthPlane = True;
+            break;
     }     
 }
 
-static void ReDial( double SaveValue[10] )
+static void ReDial( double SaveValue[10], CQRQuaternion * SaveQuat )
 {
     int index;
     
@@ -714,18 +897,26 @@ static void ReDial( double SaveValue[10] )
 	  if ( (RotMode == RotBond) && BondSelected) {
 	    BondSelected->BRotValue = DialValue[DialBRot];
 	  } else if ( RotMode == RotAll ) {
-	    WRotValue[DialRX] = DialValue[DialRX];
-	    WRotValue[DialRY] = DialValue[DialRY];
-	    WRotValue[DialRZ] = DialValue[DialRZ];
-	    WTransX = DialValue[DialTX];
-	    WTransY = DialValue[DialTY];
-	    WTransZ = DialValue[DialTZ];
+	    WorldDialValue[DialRX] = DialValue[DialRX];
+	    WorldDialValue[DialRY] = DialValue[DialRY];
+	    WorldDialValue[DialRZ] = DialValue[DialRZ];
+	    WorldDialValue[DialTX] = DialValue[DialTX];
+	    WorldDialValue[DialTY] = DialValue[DialTY];
+	    WorldDialValue[DialTZ] = DialValue[DialTZ];
+        WorldDialQRot.w = DialQRot.w;
+        WorldDialQRot.x = DialQRot.x;
+        WorldDialQRot.y = DialQRot.y;
+        WorldDialQRot.z = DialQRot.z;
 
 	  }
 	  for (index = 0; index < 7; index++) {
 	    if (!(index == DialZoom))
 	    DialValue[index] = SaveValue[index];
 	  }
+	  DialQRot.w = SaveQuat->w;
+	  DialQRot.x = SaveQuat->x;
+	  DialQRot.y = SaveQuat->y;
+	  DialQRot.z = SaveQuat->z;
 	}
 	return;
 }
@@ -736,20 +927,32 @@ void ProcessMouseMove( int x, int y, int stat )
     register MouseMapping *map;
     register int dx,dy;
     double SaveValue[10];
+    CQRQuaternion SaveQuat;
     int index;
+    
+    SaveQuat.w =  SaveQuat.x =  SaveQuat.y =  SaveQuat.z =  0;
+
 
     if (! ( RotMode == RotMol ) ) {
       for (index=0; index<10; index++)
           SaveValue[index] = DialValue[index];
+          SaveQuat.w =  DialQRot.w;
+          SaveQuat.x =  DialQRot.x;
+          SaveQuat.y =  DialQRot.y;
+          SaveQuat.z =  DialQRot.z;
       if (( RotMode == RotBond ) && BondSelected)
           DialValue[DialBRot] = BondSelected->BRotValue;
       else if ( RotMode == RotAll ) {
-          DialValue[DialRX] = WRotValue[DialRX];
-          DialValue[DialRY] = WRotValue[DialRY];
-          DialValue[DialRZ] = WRotValue[DialRZ];
-	      DialValue[DialTX] = WTransX;
-	      DialValue[DialTY] = WTransY;
-	      DialValue[DialTZ] = WTransZ;
+          DialValue[DialRX] = WorldDialValue[DialRX];
+          DialValue[DialRY] = WorldDialValue[DialRY];
+          DialValue[DialRZ] = WorldDialValue[DialRZ];
+	      DialValue[DialTX] = WorldDialValue[DialTX];
+	      DialValue[DialTY] = WorldDialValue[DialTY];
+	      DialValue[DialTZ] = WorldDialValue[DialTZ];
+	      DialQRot.w = WorldDialQRot.w;
+	      DialQRot.x = WorldDialQRot.x;
+	      DialQRot.y = WorldDialQRot.y;
+	      DialQRot.z = WorldDialQRot.z;
       }
     }
     
@@ -760,12 +963,12 @@ void ProcessMouseMove( int x, int y, int stat )
         {   InitX = PointX = x;
             InitY = PointY = y;
             HeldButton = True;
-            ReDial( SaveValue );
+            ReDial( SaveValue, &SaveQuat );
             return;
         }
     
         if( IsClose(x,InitX) && IsClose(y,InitY) ) {
-            ReDial( SaveValue );
+            ReDial( SaveValue, &SaveQuat );
             return;
         }                         
         
@@ -783,7 +986,7 @@ void ProcessMouseMove( int x, int y, int stat )
 
         if( !DrawArea )
         {  if( IsClose(x,InitX) && IsClose(y,InitY) ){
-             ReDial( SaveValue );
+             ReDial( SaveValue, &SaveQuat );
              return;
            }                         
     
@@ -826,7 +1029,7 @@ void ProcessMouseMove( int x, int y, int stat )
         HeldButton = False;
     }
 
-    ReDial( SaveValue );
+    ReDial( SaveValue, &SaveQuat );
     return;
 }
 
@@ -840,5 +1043,6 @@ void InitialiseCmndLine( void )
 
     SetMouseMode(MMRasMol);
     HeldButton = False;
+    TkSendSerial = 0;
 }
 
