@@ -1,10 +1,9 @@
-
 /***************************************************************************
- *                               RasMol 2.7.3                              *
+ *                              RasMol 2.7.5                               *
  *                                                                         *
  *                                 RasMol                                  *
  *                 Molecular Graphics Visualisation Tool                   *
- *                             6 February 2005                             *
+ *                              13 June 2009                               *
  *                                                                         *
  *                   Based on RasMol 2.6 by Roger Sayle                    *
  * Biomolecular Structures Group, Glaxo Wellcome Research & Development,   *
@@ -21,33 +20,56 @@
  *Philippe Valadon   RasTop 1.3     Aug 00     (C) Philippe Valadon 2000   *
  *                                                                         *
  *Herbert J.         RasMol 2.7.0   Mar 99     (C) Herbert J. Bernstein    * 
- *Bernstein          RasMol 2.7.1   Jun 99         1998-2001               *
+ *Bernstein          RasMol 2.7.1   Jun 99         1998-2008               *
  *                   RasMol 2.7.1.1 Jan 01                                 *
  *                   RasMol 2.7.2   Aug 00                                 *
  *                   RasMol 2.7.2.1 Apr 01                                 *
  *                   RasMol 2.7.2.1.1 Jan 04                               *
  *                   RasMol 2.7.3   Feb 05                                 *
+ *                   RasMol 2.7.3.1 Apr 06                                 *
+ *                   RasMol 2.7.4   Nov 07                                 *
+ *                   RasMol 2.7.4.1 Jan 08                                 *
+ *                   RasMol 2.7.4.2 Mar 08                                 *
+ *                   RasMol 2.7.5   May 09                                 *
  *                                                                         *
- *with RasMol 2.7.3 incorporating changes by Clarice Chigbo, Ricky Chachra,*
- *and Mamoru Yamanishi.  Work on RasMol 2.7.3 supported in part by         *
- *grants DBI-0203064, DBI-0315281 and EF-0312612 from the U.S. National    *
- *Science Foundation and grant DE-FG02-03ER63601 from the U.S. Department  *
- *of Energy.                                                               *
+ * RasMol 2.7.5 incorporates changes by T. Ikonen, G. McQuillan, N. Darakev*
+ * and L. Andrews (via the neartree package).  Work on RasMol 2.7.5        *
+ * supported in part by grant 1R15GM078077-01 from the National Institute  *
+ * of General Medical Sciences (NIGMS), U.S. National Institutes of Health *
+ * and by grant ER63601-1021466-0009501 from the Office of Biological &    *
+ * Environmental Research (BER), Office of Science, U. S. Department of    *
+ * Energy.  RasMol 2.7.4 incorporated  changes by G. Todorov, Nan Jia,     *
+ * N. Darakev, P. Kamburov, G. McQuillan, and J. Jemilawon. Work on RasMol *
+ * 2.7.4 supported in part by grant 1R15GM078077-01 from the NIGMS/NIH and *
+ * grant ER63601-1021466-0009501 from BER/DOE.  RasMol 2.7.3 incorporates  *
+ * changes by Clarice Chigbo, Ricky Chachra, and Mamoru Yamanishi.  Work   *
+ * on RasMol 2.7.3 supported in part by grants DBI-0203064, DBI-0315281    *
+ * and EF-0312612 from the U.S. National Science Foundation and grant      *
+ * DE-FG02-03ER63601 from BER/DOE. The content is solely the responsibility*
+ * of the authors and does not necessarily represent the official views of *
+ * the funding organizations.                                              *
+ *                                                                         *
+ * The code for use of RasMol under GTK in RasMol 2.7.4.2 and 2.7.5 was    *
+ * written by Teemu Ikonen.                                                *
  *                                                                         *
  *                    and Incorporating Translations by                    *
- *  Author                               Item                      Language*
+ *  Author                               Item                     Language *
  *  Isabel Servan Martinez,                                                *
- *  Jose Miguel Fernandez Fernandez      2.6   Manual              Spanish *
- *  Jose Miguel Fernandez Fernandez      2.7.1 Manual              Spanish *
- *  Fernando Gabriel Ranea               2.7.1 menus and messages  Spanish *
- *  Jean-Pierre Demailly                 2.7.1 menus and messages  French  *
+ *  Jose Miguel Fernandez Fernandez      2.6   Manual             Spanish  *
+ *  Jose Miguel Fernandez Fernandez      2.7.1 Manual             Spanish  *
+ *  Fernando Gabriel Ranea               2.7.1 menus and messages Spanish  *
+ *  Jean-Pierre Demailly                 2.7.1 menus and messages French   *
  *  Giuseppe Martini, Giovanni Paolella, 2.7.1 menus and messages          *
- *  A. Davassi, M. Masullo, C. Liotto    2.7.1 help file           Italian *
+ *  A. Davassi, M. Masullo, C. Liotto    2.7.1 help file          Italian  *
+ *  G. Pozhvanov                         2.7.3 menus and messages Russian  *
+ *  G. Todorov                           2.7.3 menus and messages Bulgarian*
+ *  Nan Jia, G. Todorov                  2.7.3 menus and messages Chinese  *
+ *  Mamoru Yamanishi, Katajima Hajime    2.7.3 menus and messages Japanese *
  *                                                                         *
  *                             This Release by                             *
- * Herbert J. Bernstein, Bernstein + Sons, P.O. Box 177, Bellport, NY, USA *
+ * Herbert J. Bernstein, Bernstein + Sons, 5 Brewster Ln, Bellport, NY, USA*
  *                       yaya@bernstein-plus-sons.com                      *
- *               Copyright(C) Herbert J. Bernstein 1998-2005               *
+ *               Copyright(C) Herbert J. Bernstein 1998-2008               *
  *                                                                         *
  *                READ THE FILE NOTICE FOR RASMOL LICENSES                 *
  *Please read the file NOTICE for important notices which apply to this    *
@@ -62,9 +84,15 @@ typedef enum {
        French      =    1,
        German      =    2,
        Italian     =    3,
-       Spanish     =    4
+       Spanish     =    4,
+       Russian     =    5,
+       Chinese     =    6,
+       Japanese    =    7,
+       Bulgarian   =    8
 } language;
 
+#define NUMLANGS 9
+
 typedef enum {
        ErrSyntax   =    0,
        ErrBigNum   =    1,
@@ -89,6 +117,12 @@ typedef enum {
        ErrBadMolDB =   20,
        ErrNoBond   =   21,
        ErrBlocSel  =   22,
+	   ErrNoToggle =  172,
+
+	   StrCCompOn  =  173,
+	   StrCCompOff =  174,
+	   StrNoTogOn  =  175,
+	   StrNoTogOff =  176,
 
        StrErrFile  =   30,
        StrNotFnd   =   31,
@@ -188,54 +222,68 @@ typedef enum {
        StrMRMol    =  127,
        StrMRAll    =  128,
 
-       StrMGIF     =  129,
-       StrMPostscr =  130,
-       StrMPPM     =  131,
-       StrMIRGB    =  132,
+       StrMBMP     =  129,
+       StrMGIF     =  130,
+       StrMIRGB    =  131,
+       StrMPPM     =  132,
        StrMSRast   =  133,
-       StrMBMP     =  134,
+       StrMPostscr =  134,
        StrMPICT    =  135,
+       StrMVECPS   =  136,
+       StrMMSCR    =  137,
+       StrMKine    =  138,
+       StrMPOVRAY  =  139,
+       StrMVRML    =  140,
+       StrMRPP     =  141,
+       StrMR3D     =  142,
+       StrMSCR     =  143,
 
-       StrMAbout   =  136,
-       StrMUserM   =  137,
+
+       StrMAbout   =  144,
+       StrMUserM   =  145,
        
-       StrMUndo    =  138,
-       StrMCut     =  139,
-       StrMCopy    =  140,
-       StrMPaste   =  141,
+       StrMUndo    =  146,
+       StrMCut     =  147,
+       StrMCopy    =  148,
+       StrMPaste   =  149,
 #ifdef APPLEMAC
-       StrMClear   =  142,
+       StrMClear   =  150,
 #else
-       StrMDelete  =  142,
+       StrMDelete  =  150,
 #endif
-       StrMSelAll  =  143,
+       StrMSelAll  =  151,
 
-       StrMFile    =  144,
-       StrMEdit    =  145,
-       StrMDisplay =  146,
-       StrMColour  =  147,
-       StrMOpt     =  148,
-       StrMSettings=  149,
-       StrMExport  =  150,
+       StrMFile    =  152,
+       StrMEdit    =  153,
+       StrMDisplay =  154,
+       StrMColour  =  155,
+       StrMOpt     =  156,
+       StrMSettings=  157,
+       StrMExport  =  158,
 #ifdef APPLEMAC
-       StrMWindow  =  151,
-       StrMHelp    =  152,
-       StrMMainWin =  153,
-       StrMCmndLin =  154,
+       StrMWindow  =  159,
+       StrMHelp    =  160,
+       StrMMainWin =  161,
+       StrMCmndLin =  162,
 #else
-       StrMHelp    =  151,
+       StrMHelp    =  159,
 #endif
 
-       StrPrmtPDB  =  155,
-       StrPrmtImg  =  156,
-       StrPrmtMol  =  157,
-       StrWarn     =  158,
-       StrChain    =  159
+       StrPrmtPDB  =  163,
+       StrPrmtImg  =  164,
+       StrPrmtMol  =  165,
+       StrWarn     =  166,
+       StrChain    =  167,
+       
+       StrRegister =  168,
+       StrDonate   =  169,
+       StrWarranty =  170,
+       StrNoShow   =  171
 
 
 } strflag;
 
-#define MaxStrFlag     160
+#define MaxStrFlag     177
 typedef struct {
       char *    msg;
       strflag   msgno;
@@ -243,19 +291,36 @@ typedef struct {
       int       aux;
 } langstr;
 
+typedef struct {
+      char *   menufontvar;
+#ifdef MSWIN
+      BYTE     menucharset;
+#endif
+      char *   menufontlist;
+      language lang;	
+} langfont;
+
 
 #ifdef LANGSEL
 
 char * MsgStrs[MaxStrFlag];
 int    MsgLens[MaxStrFlag];
 int    MsgAuxl[MaxStrFlag];
+language     Language;
+language    TermLanguage;
 
 #else
 
 extern char * MsgStrs[MaxStrFlag];
 extern int    MsgLens[MaxStrFlag];
 extern int    MsgAuxl[MaxStrFlag];
+extern language   Language;
+extern language   TermLanguage;
+extern langfont langfonts[NUMLANGS];
 
 #endif
 
 void SwitchLang( language );
+language str2lang ( const char * );
+const char * lang2str ( language lang);
+void UpdateLanguage ( void );
