@@ -1,10 +1,9 @@
-
 /***************************************************************************
- *                               RasMol 2.7.3                              *
+ *                              RasMol 2.7.5                               *
  *                                                                         *
  *                                 RasMol                                  *
  *                 Molecular Graphics Visualisation Tool                   *
- *                             6 February 2005                             *
+ *                              13 June 2009                               *
  *                                                                         *
  *                   Based on RasMol 2.6 by Roger Sayle                    *
  * Biomolecular Structures Group, Glaxo Wellcome Research & Development,   *
@@ -21,40 +20,119 @@
  *Philippe Valadon   RasTop 1.3     Aug 00     (C) Philippe Valadon 2000   *
  *                                                                         *
  *Herbert J.         RasMol 2.7.0   Mar 99     (C) Herbert J. Bernstein    * 
- *Bernstein          RasMol 2.7.1   Jun 99         1998-2001               *
+ *Bernstein          RasMol 2.7.1   Jun 99         1998-2008               *
  *                   RasMol 2.7.1.1 Jan 01                                 *
  *                   RasMol 2.7.2   Aug 00                                 *
  *                   RasMol 2.7.2.1 Apr 01                                 *
  *                   RasMol 2.7.2.1.1 Jan 04                               *
  *                   RasMol 2.7.3   Feb 05                                 *
+ *                   RasMol 2.7.3.1 Apr 06                                 *
+ *                   RasMol 2.7.4   Nov 07                                 *
+ *                   RasMol 2.7.4.1 Jan 08                                 *
+ *                   RasMol 2.7.4.2 Mar 08                                 *
+ *                   RasMol 2.7.5   May 09                                 *
  *                                                                         *
- *with RasMol 2.7.3 incorporating changes by Clarice Chigbo, Ricky Chachra,*
- *and Mamoru Yamanishi.  Work on RasMol 2.7.3 supported in part by         *
- *grants DBI-0203064, DBI-0315281 and EF-0312612 from the U.S. National    *
- *Science Foundation and grant DE-FG02-03ER63601 from the U.S. Department  *
- *of Energy.                                                               *
+ * RasMol 2.7.5 incorporates changes by T. Ikonen, G. McQuillan, N. Darakev*
+ * and L. Andrews (via the neartree package).  Work on RasMol 2.7.5        *
+ * supported in part by grant 1R15GM078077-01 from the National Institute  *
+ * of General Medical Sciences (NIGMS), U.S. National Institutes of Health *
+ * and by grant ER63601-1021466-0009501 from the Office of Biological &    *
+ * Environmental Research (BER), Office of Science, U. S. Department of    *
+ * Energy.  RasMol 2.7.4 incorporated  changes by G. Todorov, Nan Jia,     *
+ * N. Darakev, P. Kamburov, G. McQuillan, and J. Jemilawon. Work on RasMol *
+ * 2.7.4 supported in part by grant 1R15GM078077-01 from the NIGMS/NIH and *
+ * grant ER63601-1021466-0009501 from BER/DOE.  RasMol 2.7.3 incorporates  *
+ * changes by Clarice Chigbo, Ricky Chachra, and Mamoru Yamanishi.  Work   *
+ * on RasMol 2.7.3 supported in part by grants DBI-0203064, DBI-0315281    *
+ * and EF-0312612 from the U.S. National Science Foundation and grant      *
+ * DE-FG02-03ER63601 from BER/DOE. The content is solely the responsibility*
+ * of the authors and does not necessarily represent the official views of *
+ * the funding organizations.                                              *
+ *                                                                         *
+ * The code for use of RasMol under GTK in RasMol 2.7.4.2 and 2.7.5 was    *
+ * written by Teemu Ikonen.                                                *
  *                                                                         *
  *                    and Incorporating Translations by                    *
- *  Author                               Item                      Language*
+ *  Author                               Item                     Language *
  *  Isabel Servan Martinez,                                                *
- *  Jose Miguel Fernandez Fernandez      2.6   Manual              Spanish *
- *  Jose Miguel Fernandez Fernandez      2.7.1 Manual              Spanish *
- *  Fernando Gabriel Ranea               2.7.1 menus and messages  Spanish *
- *  Jean-Pierre Demailly                 2.7.1 menus and messages  French  *
+ *  Jose Miguel Fernandez Fernandez      2.6   Manual             Spanish  *
+ *  Jose Miguel Fernandez Fernandez      2.7.1 Manual             Spanish  *
+ *  Fernando Gabriel Ranea               2.7.1 menus and messages Spanish  *
+ *  Jean-Pierre Demailly                 2.7.1 menus and messages French   *
  *  Giuseppe Martini, Giovanni Paolella, 2.7.1 menus and messages          *
- *  A. Davassi, M. Masullo, C. Liotto    2.7.1 help file           Italian *
+ *  A. Davassi, M. Masullo, C. Liotto    2.7.1 help file          Italian  *
+ *  G. Pozhvanov                         2.7.3 menus and messages Russian  *
+ *  G. Todorov                           2.7.3 menus and messages Bulgarian*
+ *  Nan Jia, G. Todorov                  2.7.3 menus and messages Chinese  *
+ *  Mamoru Yamanishi, Katajima Hajime    2.7.3 menus and messages Japanese *
  *                                                                         *
  *                             This Release by                             *
- * Herbert J. Bernstein, Bernstein + Sons, P.O. Box 177, Bellport, NY, USA *
+ * Herbert J. Bernstein, Bernstein + Sons, 5 Brewster Ln, Bellport, NY, USA*
  *                       yaya@bernstein-plus-sons.com                      *
- *               Copyright(C) Herbert J. Bernstein 1998-2005               *
+ *               Copyright(C) Herbert J. Bernstein 1998-2008               *
  *                                                                         *
  *                READ THE FILE NOTICE FOR RASMOL LICENSES                 *
  *Please read the file NOTICE for important notices which apply to this    *
  *package and for license terms (GPL or RASLIC).                           *
  ***************************************************************************/
 /* molecule.h
- $Log: molecule.h,v $
+ $Log$
+ Revision 1.9  2008/06/11 01:40:54  yaya
+ Improve gradient for map surfaces and brighten image;
+ Add parenthesized selections before all commands;
+ Change saveSelection and loadSelection to
+ SaveAtomSelection and LoadAtomSelection -- HJB
+
+ Revision 1.8  2008/06/09 17:48:11  hk0i
+ added loadSelection() and saveSelection() routines for new color commands. *gm*
+
+ Revision 1.7  2008/03/22 18:42:53  yaya
+ Post release cleanup and credit to Ikonen in file headers. -- HJB
+
+ Revision 1.6  2008/03/17 03:01:31  yaya
+ Update to agree with 2.7.4.2 release and T. Ikonen GTK mods -- HJB
+
+ Revision 1.3  2008/03/17 01:32:41  yaya
+ Add gtk mods by tpikonen, and intergate with 2.7.4.2 mods -- HJB
+
+ Revision 1.5  2008/03/16 22:25:22  yaya
+ Align comments with production version; Update rasmol_install and
+ rasmol_run shell scripts for Japanese and Chinese; Align logic for
+ positioning and sizing initial window with windows version -- HJB
+
+ Revision 1.2  2008/01/28 03:29:37  yaya
+ Update CVS to RasMol_2.7.4.1 -- HJB
+
+ Revision 1.4  2007/11/19 03:28:39  yaya
+ Update to credits for 2.7.4 in manual and headers
+ Mask code added -- HJB
+
+ Revision 1.3  2007/10/23 02:27:55  yaya
+ Preliminary mods for revised PDB format derived from Rutgers mods.
+ Partial changes for map tangles -- HJB
+
+ Revision 1.2  2007/07/02 12:44:39  yaya
+ Partial preliminary map code -- HJB
+
+ Revision 1.1.1.1  2007/03/01 01:16:33  todorovg
+ Chinese working versio from rasmol_ru initial import
+
+ Revision 1.3  2006/11/01 03:23:50  yaya
+ Update NSIS windows installer for more script types and to fix
+ misplaced script instructions for data files; add document and
+ script icons directly in raswin.exe; add credit line to
+ G. A. Pozhvanov in comments for Russian translations. -- HJB
+
+ Revision 1.2  2006/09/17 10:53:55  yaya
+ Clean up headers and start on code for X11 -- HJB
+
+ Revision 1.1.1.1  2006/09/16 18:45:51  yaya
+ Start of RasMol Russian Translation Project based on translations
+ by Gregory A. Pozhvanov of Saint Petersburg State University -- HJB
+
+ Revision 1.1.1.1  2006/06/19 22:05:14  todorovg
+ Initial Rasmol 2.7.3 Import
+
  Revision 1.1  2004/05/07 19:46:16  yaya
  Initial revision
 
@@ -86,37 +164,43 @@
  Parametrization for alt conformer bond radius
 
  */
+
+#ifndef MOLECULE_H
+#define MOLECULE_H
+#include <CVector.h>
+
 #define MAXMASK 40
 #define MAXELEM 1024
 #define MINELEM 29
-#define MAXRES  100
-#define MINRES  54
+#define MAXRES  104
+#define MINRES  59
+#define MAXCHIDENT 512
+#define MINCHIDENT 54
 #define CIS     90  /* max. omega-angle to form a cis-peptide bond */
 
 
 #define IsAmino(x)       ((x)<=23)
-#define IsAminoNucleo(x) ((x)<=42)
-#define IsNucleo(x)      (((x)>=24) && ((x)<=42))
+#define IsAminoNucleo(x) ((x)<=42 || ((x)>=54 && (x)<=58))
+#define IsNucleo(x)      ((((x)>=24) && ((x)<=42)) || ((x)>=54 && (x)<=58))
 #define IsProtein(x)     (((x)<=23) || (((x)>=43) && ((x)<=45)))
-#define IsDNA(x)         (((x)>=24) && ((x)<=27))
+#define IsDNA(x)         ((((x)>=24) && ((x)<=27))||  ((x)>=54 && (x)<=58))
 #define IsSolvent(x)     (((x)>=46) && ((x)<=49))
 #define IsWater(x)       (((x)==46) || ((x)==47))
 #define IsIon(x)         (((x)==48) || ((x)==49))
 
 #define IsPyrimidine(x)  (IsCytosine(x) || IsThymine(x))
 #define IsPurine(x)      (IsAdenine(x) || IsGuanine(x))
-#define IsRNA(x)         (IsNucleo(x) && !IsThymine(x))
+#define IsRNA(x)         ((((x)>=24) && ((x)<=26)) || ((x)>=28 && (x)<=42))
 #define NucleicCompl(x)  ((x)^3)
 
 
 #define IsProline(x)     ((x)==11)
 #define IsCysteine(x)    ((x)==17)
-#define IsAdenine(x)     ((x)==24)
-#define IsCytosine(x)    ((x)==25)
-#define IsGuanine(x)     ((x)==26)
-#define IsThymine(x)     ((x)==27)
-
 
+#define IsAdenine(x)     ((x)==24 || (x)==54)
+#define IsCytosine(x)    ((x)==25 || (x)==55 )
+#define IsGuanine(x)     ((x)==26 || (x)==56 )
+#define IsThymine(x)     ((x)==27 || (x)==57 )
 
 #define IsAlphaCarbon(x)     ((x)==1)
 #define IsSugarPhosphate(x)  ((x)==7)
@@ -133,6 +217,7 @@
 /*=================*/
 
 #define SelectFlag      0x01
+#define SaveFlag		0x1000
 #define DrawBondFlag    0x0e
 #define AllAtomFlag     0x1c
 #define HelixFlag       0x03
@@ -150,6 +235,7 @@
 #define TouchFlag       0x100    /* Touch by probe                 */
 #define ExpandFlag      0x200    /* Expand by probe radius         */
 #define SurfBondFlag    0x400    /* Atom is part of a surface bond */
+#define FieldFlag       0x800    /* Atom has an auxilliary field   */
 
 
 /* Bond Flags */
@@ -186,16 +272,34 @@
 /*  Molecule Database  */
 /*=====================*/
 
-#define MaxBonds 6
+#define MaxSDepth 4
+
 
 typedef struct _Atom {
         struct _Atom __far *anext;        /* Linked list of atoms  */
         struct _Atom __far *bucket;       /* Sphere Y-Bucket       */
         struct _Atom __far *next;         /* Active Object List    */
+        void __far * pargroup;            /* Parent Group          */ 
         Long   xorg, yorg, zorg;          /* World Co-ordinates    */
         Long   fxorg, fyorg, fzorg;       /* Offsets for rotations */
         Long   x, y, z;                   /* Image Co-ordinates    */
                                           /* also used as scratch  */
+        /* auxillary coordinates are field vectors based on
+           the current atom.  The world coordinates are relative
+           to the atom.  The Image coordinates are absolute */ 
+                    
+        Long   fieldworg, fieldxorg, fieldyorg, fieldzorg;
+                                          /* World aux coords      */
+        Long   basexorg, baseyorg, basezorg;
+                                          /* base perp to field    */
+        Long   fieldw, fieldx, fieldy, fieldz;
+                                          /* Image aux coords      */
+        Long   basex, basey, basez;
+                                          /* image base per coords */
+        short  fieldcol;                  /* Field Colour          */
+        short  fieldradius;               /* Field vector radius   */
+        short  fieldirad;                 /* Field image radius    */
+        
         short  xtrl, ytrl, ztrl;          /* Trailing Bits         */
         short  radius;                    /* World Radius          */
         short  temp;                      /* Temperature Factor    */
@@ -210,16 +314,28 @@ typedef struct _Atom {
         short  mbox;                      /* Shadow Casting NOnce  */
         short  model;                     /* Atom Model Number     */
         short  visited;                   /* For bond rotation     */
-        short  nbonds;                    /* For bond rotation     */ 
-        struct _Atom __far *bonds[MaxBonds];
-        void   *surfbonds;                /* Surface bonds list    */
+        int    nexttarget;                /* For sorts             */
+        Long   ordinal;                   /* ordinal of this atom  */
+        Long   ordlist[MaxSDepth+1];      /* ordinal in template matching  */
+        CVectorHandle bondsvector;        /* For Align and bond rotation */
+        CVectorHandle distancevector;     /* For Align             */
     } RAtom;
 
+/*  notes on ordlist:
+    For the atoms in a template, ordlist holds the ordinals in the
+    target molecule that match.  Zero means not assigned.
+
+    For the atoms in a target, ordlist holds the orinals in the
+    template that match.  Zero means not assigned.
+
+ */
+
 
 typedef struct _Bond {
         struct _Bond __far *bnext;       /* Linked list of bonds  */
         RAtom __far *srcatom;            /* Source Atom Ptr       */
         RAtom __far *dstatom;            /* Destination Atom Ptr  */
+        long  sxyz;                      /* Bond length           */
         short radius;                    /* World Radius          */
         short irad;                      /* Image Radius          */
         short aradius;                   /* World Alt Radius      */
@@ -246,7 +362,8 @@ typedef struct _SurfBond {
 
 typedef struct _Group {
         struct _Group __far *gnext;       /* Linked list of groups */
-        RAtom __far *alist;                /* Linked list of atoms  */
+        RAtom __far *alist;               /* Linked list of atoms  */
+        void __far *parchain;             /* Parent Chain          */
         short serno;                      /* Group serial number   */
         short sserno;                     /* Secondary serial no.  */ 
         short width;                      /* Ribbon Width          */
@@ -258,6 +375,7 @@ typedef struct _Group {
         Byte  struc;                      /* Secondary Structure   */
         short flag;                       /* Database flags        */
         short model;                      /* Group Model Number    */
+        short tempmarker;                 /* Temporary Marker      */
     } Group;
  
 #ifdef APPLEMAC
@@ -267,9 +385,10 @@ typedef struct _Group {
 
 typedef struct _ChainSeg {
         struct _ChainSeg __far *cnext;    /* Linked list of chains     */
+        void __far * parmolecule;         /* Parent Molecule           */
         Group __far *glist;               /* Linked list of groups     */
         Bond __far *blist;                /* Linked list of back bonds */
-        char ident;                       /* Chain identifier          */
+        int  chrefno;                     /* Chain identifier refno    */
         Byte model;                       /* NMR Model / Symmetry      */
     } Chain;
 
@@ -288,8 +407,8 @@ typedef struct _HBond {
         short energy;                     /* Hydrogen bond energy     */
         short radius;                     /* World Radius             */
         short irad;                       /* Image Radius             */
-        short aradius;                    /* World Alt Radius      */
-        short iarad;                      /* Image Alt Radius      */
+        short aradius;                    /* World Alt Radius         */
+        short iarad;                      /* Image Alt Radius         */
         Char offset;                      /* Signed Offset            */
         short flag;                       /* Database flags           */
         Byte col;                         /* Hydrogen bond colour     */
@@ -371,10 +490,18 @@ void RegisterAlloc(void __far * );
 void FreeAlloc(void __far * );
 
 /* used to describe an defined part of the selected molecule */
-typedef enum{NO, ATM, CRD, GRP, CHN} Selection;
-
+typedef enum{NO, ATM, CRD, GRP, CHN, MDL} Selection;
 
+#include <CNearTree.h>
 #ifdef MOLECULE
+char ChIdents[MAXCHIDENT][5] = {
+    "A","B","C","D","E","F","G","H","I","J",
+    "K","L","M","N","O","P","Q","R","S","T",
+    "U","V","W","X","Y","Z",
+    "a","b","c","d","e","f","g","h","i","j",
+    "k","l","m","n","o","p","q","r","s","t",
+    "u","v","w","x","y","z"," ","*"};
+    
 /* Avoid SGI Compiler Warnings! */
 char Residue[MAXRES][4] = {
     /*===============*/
@@ -415,7 +542,14 @@ char Residue[MAXRES][4] = {
     /*=================*/
           "UNK", "ACE", "FOR", "HOH",
           "DOD", "SO4", "PO4", "NAD",
-          "COA", "NAP", "NDP"  };
+          "COA", "NAP", "NDP",
+          
+    /*==========================================*/
+    /*  DNA Nucleotides PDB Revision, Jul 2007  */
+    /*==========================================*/
+    
+         " DA", " DC", " DG", " DT"," DI" 
+};
 
 
 /* Avoid SGI Compiler Warnings! */
@@ -481,7 +615,7 @@ Molecule __far *Database;
 MaskDesc UserMask[MAXMASK];
 Long MinHBondDist, MaxHBondDist;
 Long MinBondDist,  MaxBondDist;
-int ElemNo,ResNo;
+int ElemNo,ResNo,ChNo;
 int HasHydrogen;
 int MaskCount;
 int NMRModel;
@@ -495,7 +629,12 @@ HBond __far *FreeHBond;
 Bond __far *FreeBond;
 Bond __far *NewBond;
 
+CNearTreeHandle AtomTree;
+int NeedAtomTree;
+
+
 #else
+extern char ChIdents[MAXCHIDENT][5];
 extern char Residue[MAXRES][4];
 extern char ElemDesc[MAXELEM][12];
 extern InfoStruct Info;
@@ -528,7 +667,7 @@ extern Molecule __far *Database;
 extern MaskDesc UserMask[MAXMASK];
 extern Long MinHBondDist, MaxHBondDist;
 extern Long MinBondDist,  MaxBondDist;
-extern int ElemNo,ResNo;
+extern int ElemNo,ResNo,ChNo;
 extern int HasHydrogen;
 extern int MaskCount;
 extern int NMRModel;
@@ -542,6 +681,9 @@ extern HBond __far *FreeHBond;
 extern Bond __far *FreeBond;
 extern Bond __far *NewBond;
 
+extern CNearTreeHandle AtomTree;
+extern int NeedAtomTree;
+
 #ifndef APPLEMAC
 #define RegisterAlloc(x)
 #endif
@@ -553,9 +695,12 @@ void ProcessGroup( int );
 void CreateMolGroup( void );
 void CreateNextMolGroup( void );
 int FindResNo( char* );
+int FindResNo( char __far * );
+int FindChNo( char __far *);
 
 RAtom __far *CreateAtom( void );
 RAtom __far *FindGroupAtom( Group __far*, int );
+void ProcessAtomType( RAtom __far*, char[2] );
 void ProcessAtom( RAtom __far* );
 
 int NewAtomType( char* );
@@ -566,7 +711,10 @@ Bond __far *ProcessBond( RAtom __far*, RAtom __far*, int );
 void CreateBond( Long, Long, int );
 void CreateBondOrder( Long, Long );
 void CreateNewBond( Long, Long );
+int PreTestSurface(  RAtom __far *,  RAtom __far *, 
+                   Long [3],  int *, Long [3] );
 void CreateMoleculeBonds( int, int, int );
+int CreateAtomTree( void );
 void CreateSurfaceBonds( void );
 RAtom __far *FindCysSulphur( Group __far *group );
 void FindDisulphideBridges( void );
@@ -587,7 +735,11 @@ void ReviseTitle( void );
 void DescribeMolecule( void );
 void DestroyDatabase( void );
 void PurgeDatabase( void );
+
+void LoadAtomSelection( void );
+void SaveAtomSelection( void );
 #ifdef APPLEMAC
 void RegisterAlloc( void *);
 #endif
 
+#endif
