@@ -1,10 +1,9 @@
-
 /***************************************************************************
- *                               RasMol 2.7.3                              *
+ *                              RasMol 2.7.5                               *
  *                                                                         *
  *                                 RasMol                                  *
  *                 Molecular Graphics Visualisation Tool                   *
- *                             6 February 2005                             *
+ *                              13 June 2009                               *
  *                                                                         *
  *                   Based on RasMol 2.6 by Roger Sayle                    *
  * Biomolecular Structures Group, Glaxo Wellcome Research & Development,   *
@@ -21,40 +20,131 @@
  *Philippe Valadon   RasTop 1.3     Aug 00     (C) Philippe Valadon 2000   *
  *                                                                         *
  *Herbert J.         RasMol 2.7.0   Mar 99     (C) Herbert J. Bernstein    * 
- *Bernstein          RasMol 2.7.1   Jun 99         1998-2001               *
+ *Bernstein          RasMol 2.7.1   Jun 99         1998-2008               *
  *                   RasMol 2.7.1.1 Jan 01                                 *
  *                   RasMol 2.7.2   Aug 00                                 *
  *                   RasMol 2.7.2.1 Apr 01                                 *
  *                   RasMol 2.7.2.1.1 Jan 04                               *
  *                   RasMol 2.7.3   Feb 05                                 *
+ *                   RasMol 2.7.3.1 Apr 06                                 *
+ *                   RasMol 2.7.4   Nov 07                                 *
+ *                   RasMol 2.7.4.1 Jan 08                                 *
+ *                   RasMol 2.7.4.2 Mar 08                                 *
+ *                   RasMol 2.7.5   May 09                                 *
  *                                                                         *
- *with RasMol 2.7.3 incorporating changes by Clarice Chigbo, Ricky Chachra,*
- *and Mamoru Yamanishi.  Work on RasMol 2.7.3 supported in part by         *
- *grants DBI-0203064, DBI-0315281 and EF-0312612 from the U.S. National    *
- *Science Foundation and grant DE-FG02-03ER63601 from the U.S. Department  *
- *of Energy.                                                               *
+ * RasMol 2.7.5 incorporates changes by T. Ikonen, G. McQuillan, N. Darakev*
+ * and L. Andrews (via the neartree package).  Work on RasMol 2.7.5        *
+ * supported in part by grant 1R15GM078077-01 from the National Institute  *
+ * of General Medical Sciences (NIGMS), U.S. National Institutes of Health *
+ * and by grant ER63601-1021466-0009501 from the Office of Biological &    *
+ * Environmental Research (BER), Office of Science, U. S. Department of    *
+ * Energy.  RasMol 2.7.4 incorporated  changes by G. Todorov, Nan Jia,     *
+ * N. Darakev, P. Kamburov, G. McQuillan, and J. Jemilawon. Work on RasMol *
+ * 2.7.4 supported in part by grant 1R15GM078077-01 from the NIGMS/NIH and *
+ * grant ER63601-1021466-0009501 from BER/DOE.  RasMol 2.7.3 incorporates  *
+ * changes by Clarice Chigbo, Ricky Chachra, and Mamoru Yamanishi.  Work   *
+ * on RasMol 2.7.3 supported in part by grants DBI-0203064, DBI-0315281    *
+ * and EF-0312612 from the U.S. National Science Foundation and grant      *
+ * DE-FG02-03ER63601 from BER/DOE. The content is solely the responsibility*
+ * of the authors and does not necessarily represent the official views of *
+ * the funding organizations.                                              *
+ *                                                                         *
+ * The code for use of RasMol under GTK in RasMol 2.7.4.2 and 2.7.5 was    *
+ * written by Teemu Ikonen.                                                *
  *                                                                         *
  *                    and Incorporating Translations by                    *
- *  Author                               Item                      Language*
+ *  Author                               Item                     Language *
  *  Isabel Servan Martinez,                                                *
- *  Jose Miguel Fernandez Fernandez      2.6   Manual              Spanish *
- *  Jose Miguel Fernandez Fernandez      2.7.1 Manual              Spanish *
- *  Fernando Gabriel Ranea               2.7.1 menus and messages  Spanish *
- *  Jean-Pierre Demailly                 2.7.1 menus and messages  French  *
+ *  Jose Miguel Fernandez Fernandez      2.6   Manual             Spanish  *
+ *  Jose Miguel Fernandez Fernandez      2.7.1 Manual             Spanish  *
+ *  Fernando Gabriel Ranea               2.7.1 menus and messages Spanish  *
+ *  Jean-Pierre Demailly                 2.7.1 menus and messages French   *
  *  Giuseppe Martini, Giovanni Paolella, 2.7.1 menus and messages          *
- *  A. Davassi, M. Masullo, C. Liotto    2.7.1 help file           Italian *
+ *  A. Davassi, M. Masullo, C. Liotto    2.7.1 help file          Italian  *
+ *  G. Pozhvanov                         2.7.3 menus and messages Russian  *
+ *  G. Todorov                           2.7.3 menus and messages Bulgarian*
+ *  Nan Jia, G. Todorov                  2.7.3 menus and messages Chinese  *
+ *  Mamoru Yamanishi, Katajima Hajime    2.7.3 menus and messages Japanese *
  *                                                                         *
  *                             This Release by                             *
- * Herbert J. Bernstein, Bernstein + Sons, P.O. Box 177, Bellport, NY, USA *
+ * Herbert J. Bernstein, Bernstein + Sons, 5 Brewster Ln, Bellport, NY, USA*
  *                       yaya@bernstein-plus-sons.com                      *
- *               Copyright(C) Herbert J. Bernstein 1998-2005               *
+ *               Copyright(C) Herbert J. Bernstein 1998-2008               *
  *                                                                         *
  *                READ THE FILE NOTICE FOR RASMOL LICENSES                 *
  *Please read the file NOTICE for important notices which apply to this    *
  *package and for license terms (GPL or RASLIC).                           *
  ***************************************************************************/
 /* mswin31.c
- $Log: mswin31.c,v $
+ $Log$
+ Revision 1.8  2008/06/27 02:47:58  yaya
+ Finished update of windows code for 32-bit color -- HJB
+
+ Revision 1.7  2008/06/11 01:40:54  yaya
+ Improve gradient for map surfaces and brighten image;
+ Add parenthesized selections before all commands;
+ Change saveSelection and loadSelection to
+ SaveAtomSelection and LoadAtomSelection -- HJB
+
+ Revision 1.6  2008/03/22 17:06:48  yaya
+ Post release cleanup with credits to Ikonen in file headers. -- HJB
+
+ Revision 1.5  2008/03/21 19:13:47  yaya
+ Update documentation and comments -- HJB
+
+ Revision 1.5  2008/03/17 03:01:31  yaya
+ Update to agree with 2.7.4.2 release and T. Ikonen GTK mods -- HJB
+
+ Revision 1.4  2008/03/17 01:32:41  yaya
+ Add gtk mods by tpikonen, and intergate with 2.7.4.2 mods -- HJB
+
+ Revision 1.3  2008/03/16 22:38:09  yaya
+ Update stable release to 2.7.4.2; Update rasmol_install and rasmol_run
+ scripts to handle Japanese and Chiness (using cxterm), changing
+ Japanese for unix back to EUCJP; and align command line options
+ to set initial window size and position to agree between unix and
+ windows -- HJB
+
+ Revision 1.4  2008/03/16 22:25:22  yaya
+ Align comments with production version; Update rasmol_install and
+ rasmol_run shell scripts for Japanese and Chinese; Align logic for
+ positioning and sizing initial window with windows version -- HJB
+
+ Revision 1.3  2008/03/09 18:04:06  yaya
+ As per a suggestion by Gregory A. Pozhvanov, fixed handling of quoted
+ filename strings in raswin and added new command line options
+ -width nnnn, -height nnnn, -xpos nnnn, and -ypos nnnn. -- HJB
+
+ Revision 1.2  2008/01/28 03:29:37  yaya
+ Update CVS to RasMol_2.7.4.1 -- HJB
+
+ Revision 1.2  2007/11/25 04:11:58  yaya
+ Updates to map mask logic and inverse transforms -- HJB
+
+ Revision 1.1.1.1  2007/03/01 01:16:33  todorovg
+ Chinese working versio from rasmol_ru initial import
+
+ Revision 1.4  2006/11/01 03:23:50  yaya
+ Update NSIS windows installer for more script types and to fix
+ misplaced script instructions for data files; add document and
+ script icons directly in raswin.exe; add credit line to
+ G. A. Pozhvanov in comments for Russian translations. -- HJB
+
+ Revision 1.3  2006/10/02 21:24:49  yaya
+ Changes to allow disabling of about dialog using RASWIN.FLG flag file,
+ Restore windows Help menu adding register and donate menu items
+ Enable language support for about dialog -- HJB
+
+ Revision 1.2  2006/09/17 10:53:55  yaya
+ Clean up headers and start on code for X11 -- HJB
+
+ Revision 1.1.1.1  2006/09/16 18:45:52  yaya
+ Start of RasMol Russian Translation Project based on translations
+ by Gregory A. Pozhvanov of Saint Petersburg State University -- HJB
+
+ Revision 1.1.1.1  2006/06/19 22:05:14  todorovg
+ Initial Rasmol 2.7.3 Import
+
  Revision 1.1  2004/05/07 19:46:16  yaya
  Initial revision
 
@@ -101,6 +191,7 @@ static HMENU hMenu;
 
 void AllocateColourMap( void )
 {
+#ifdef EIGHTBIT			
     register COLORREF ref;      
     register int i;
     
@@ -130,7 +221,8 @@ void AllocateColourMap( void )
        if( ULut[i] )
        {   ref = RGB(RLut[i],GLut[i],BLut[i]);
            Lut[i] = GetNearestPaletteIndex(ColourMap,ref);
-       }    
+       } 
+#endif   
 }
 
 
@@ -148,7 +240,9 @@ int CreateImage( void )
 
 void TransferImage( void )
 {
+#ifdef EIGHTBIT
     HPALETTE OldCMap;
+#endif
     HDC hDC;
         
     if( PixMap )
@@ -161,16 +255,19 @@ void TransferImage( void )
     FBuffer = (Pixel  __huge*)GlobalLock(FBufHandle);
     /* CreateBitMap(XRange,YRange,1,8,FBuffer); */
 
+#ifdef EIGHTBIT
     if( ColourMap )
     {   OldCMap = SelectPalette(hDC,ColourMap,FALSE);
         RealizePalette(hDC);  /* GDI Bug?? */
     }
+#endif
         
     PixMap = CreateDIBitmap( hDC, (BITMAPINFOHEADER __far *)BitInfo, 
                              CBM_INIT, FBuffer, BitInfo, DIB_RGB_COLORS);
-        
+#ifdef EIGHTBIT
     if( ColourMap && OldCMap )                         
         SelectPalette(hDC,OldCMap,False);
+#endif
 
     GlobalUnlock(FBufHandle);
     ReleaseDC(NULL,hDC);
@@ -303,14 +400,22 @@ int ClipboardImage( void )
 
         if( PixMap )
         {   len = (long)XRange*YRange*sizeof(Pixel);
+#ifdef EIGHTBIT
             size = sizeof(BITMAPINFOHEADER) + 256*sizeof(RGBQUAD);
+#else
+            size = sizeof(BITMAPINFOHEADER);
+#endif
             if( (hand=GlobalAlloc(GHND,size+len)) )
             {   bitmap = (BITMAPINFO __far *)GlobalLock(hand);
                 bitmap->bmiHeader.biSize = sizeof(BITMAPINFOHEADER);
                 bitmap->bmiHeader.biWidth = XRange;
                 bitmap->bmiHeader.biHeight = YRange;
                 bitmap->bmiHeader.biPlanes = 1;
+#ifdef EIGHTBIT
                 bitmap->bmiHeader.biBitCount = 8;
+#else
+                bitmap->bmiHeader.biBitCount = 32;
+#endif
                 bitmap->bmiHeader.biCompression = BI_RGB;
                 bitmap->bmiHeader.biSizeImage = len;
                 bitmap->bmiHeader.biXPelsPerMeter = 0;
@@ -318,16 +423,22 @@ int ClipboardImage( void )
                 bitmap->bmiHeader.biClrImportant = 0;
                 bitmap->bmiHeader.biClrUsed = 0;
 
+#ifdef EIGHTBIT
                 for( i=0; i<256; i++ )
                     if( ULut[i] )
                     {   bitmap->bmiColors[Lut[i]].rgbBlue  = BLut[i];
                         bitmap->bmiColors[Lut[i]].rgbGreen = GLut[i];
                         bitmap->bmiColors[Lut[i]].rgbRed   = RLut[i];
                     }
+#endif
 
 
                 src = (Pixel __huge*)GlobalLock(FBufHandle);
+#ifdef EIGHTBIT
                 dst = ((Pixel __huge*)bitmap)+size;
+#else
+                dst = ((Pixel __huge*)bitmap)+size/4;
+#endif
 
                 /* Transfer the frame buffer */
                 while( len-- ) *dst++ = *src++;
@@ -368,8 +479,9 @@ void UpdateScrollBars( void )
 void ReDrawWindow( void )
 {
  
-  HMENU mentop[8];
-  int ii;
+  HMENU mentop[20];
+  MENUITEMINFO miteminfo;
+  int ii, nmen;
 
   ModifyMenu(hMenu,IDM_OPEN,     MF_STRING, IDM_OPEN,    MsgStrs[StrMOpen]);
   ModifyMenu(hMenu,IDM_INFO,     MF_STRING, IDM_INFO,    MsgStrs[StrMInfo]);
@@ -429,21 +541,49 @@ void ReDrawWindow( void )
  
   ModifyMenu(hMenu,IDM_BMP,      MF_STRING,IDM_BMP,      MsgStrs[StrMBMP]);
   ModifyMenu(hMenu,IDM_GIF,      MF_STRING,IDM_GIF,      MsgStrs[StrMGIF]);
-  ModifyMenu(hMenu,IDM_EPSF,     MF_STRING,IDM_EPSF,     MsgStrs[StrMPostscr]);
+  ModifyMenu(hMenu,IDM_IRIS,     MF_STRING,IDM_IRIS,     MsgStrs[StrMIRGB]);
   ModifyMenu(hMenu,IDM_PPM,      MF_STRING,IDM_PPM,      MsgStrs[StrMPPM]);
   ModifyMenu(hMenu,IDM_RAST,     MF_STRING,IDM_RAST,     MsgStrs[StrMSRast]);
+  ModifyMenu(hMenu,IDM_EPSF,     MF_STRING,IDM_EPSF,     MsgStrs[StrMPostscr]);
+  ModifyMenu(hMenu,IDM_PICT,     MF_STRING,IDM_PICT,     MsgStrs[StrMPICT]);
+  ModifyMenu(hMenu,IDM_VECPS,    MF_STRING,IDM_VECPS,    MsgStrs[StrMVECPS]);
+  ModifyMenu(hMenu,IDM_MOLSCRIPT,MF_STRING,IDM_MOLSCRIPT,MsgStrs[StrMMSCR]);
+  ModifyMenu(hMenu,IDM_KINEMAGE, MF_STRING,IDM_KINEMAGE, MsgStrs[StrMKine]);
+  ModifyMenu(hMenu,IDM_POVRAY,   MF_STRING,IDM_POVRAY,   MsgStrs[StrMPOVRAY]);
+  ModifyMenu(hMenu,IDM_VRML,     MF_STRING,IDM_VRML,     MsgStrs[StrMVRML]);
+  ModifyMenu(hMenu,IDM_RPP,      MF_STRING,IDM_RPP,      MsgStrs[StrMRPP]);
+  ModifyMenu(hMenu,IDM_R3D,      MF_STRING,IDM_R3D,      MsgStrs[StrMR3D]);
+  ModifyMenu(hMenu,IDM_SCR,      MF_STRING,IDM_SCR,      MsgStrs[StrMSCR]);
 
-  ModifyMenu(hMenu,IDM_ABOUT,    MF_STRING,IDM_ABOUT,    MsgStrs[StrMAbout]);
-  ModifyMenu(hMenu,IDM_HELP,     MF_STRING,IDM_HELP,     MsgStrs[StrMUserM]);
+  ModifyMenu(hMenu,IDM_SPLASH,   MF_STRING,IDM_SPLASH,   MsgStrs[StrMAbout]);
+  ModifyMenu(hMenu,IDM_RMANUAL,  MF_STRING,IDM_RMANUAL,  MsgStrs[StrMUserM]);
+  ModifyMenu(hMenu,IDM_REGISTER, MF_STRING,IDM_REGISTER, MsgStrs[StrRegister]);
+  ModifyMenu(hMenu,IDM_DONATE,   MF_STRING,IDM_DONATE,   MsgStrs[StrDonate]);
   
-  for (ii = 8; ii > 0; ii--) {
+  
+
+  nmen = GetMenuItemCount(hMenu);
+  if (nmen > 20) nmen = 20;
+  
+/*  
+  for (ii = nmen; ii > 0; ii--) {
     mentop[ii-1] = GetSubMenu(hMenu,ii-1);
     RemoveMenu(hMenu,ii-1,MF_BYPOSITION);
   }
-  for (ii = 0; ii < 8; ii++) {
+  for (ii = 0; ii < nmen; ii++) {
     AppendMenu(hMenu, MF_POPUP | MF_STRING , (UINT) mentop[ii], MsgStrs[StrMFile+ii]);
+  } 
+*/
+  
+  for (ii = 0; ii < nmen; ii++) {
+    miteminfo.cbSize = sizeof(MENUITEMINFO);
+    miteminfo.fMask = MIIM_TYPE;
+    miteminfo.fType = MFT_STRING;
+    miteminfo.dwTypeData =  MsgStrs[StrMFile+ii];
+  	SetMenuItemInfo(hMenu,ii,True,&miteminfo);
   }
   
+  EnableMenus(True);
   DrawMenuBar(CanvWin);
 
 }
@@ -491,6 +631,7 @@ int OpenDisplay( HANDLE instance, int mode )
     register int i,size;
     long style;
     RECT rect;
+    LONG XPOS, YPOS;
     static char VersionStr[50];
 
     sprintf (VersionStr,"RasMol Version %s", VERSION);
@@ -505,24 +646,41 @@ int OpenDisplay( HANDLE instance, int mode )
 
     for( i=0; i<10; i++ )
          DialValue[i] = 0.0;
+         
+    CQRMSet(DialQRot,0.,0.,0.,0.);
+    CQRMSet(AuxQRot,0.,0.,0.,0.);
 
     ULut[0] = True;
     RLut[0] = GLut[0] = BLut[0] = 0;
-    XRange = DefaultWide;   WRange = XRange>>1;
-    YRange = DefaultHigh;   HRange = YRange>>1;
+
+    XRange = DefaultWide;
+    YRange = DefaultHigh;
+    
+    if (InitWidth  >= 48) XRange = InitWidth;
+    if (InitHeight >= 48) YRange = InitHeight;
+
+    WRange = XRange>>1;
+    HRange = YRange>>1;
     Range = MinFun(XRange,YRange);
     ZRange = 20000;
-    
-    rect.top  = 0;   rect.bottom = YRange;
-    rect.left = 0;   rect.right  = XRange;
 
-    
+    rect.top = InitYPos;
+    rect.left = InitXPos;
+    rect.bottom = InitYPos+YRange;
+    rect.right = InitXPos+XRange;
+      
     style = WS_OVERLAPPEDWINDOW | WS_HSCROLL | WS_VSCROLL;
 
     hMenu = LoadMenu(instance,"RasWinMenu");
     AdjustWindowRect(&rect,style,TRUE);
+
+    XPOS = YPOS = CW_USEDEFAULT;
+    
+    if (InitXPos > 0 && rect.left > 0 ) XPOS = rect.left;
+    if (InitYPos > 0 && rect.top > 0) YPOS = rect.top;
+
     CanvWin = CreateWindow("RasWinClass",VersionStr, style,
-                            CW_USEDEFAULT, CW_USEDEFAULT,
+                            XPOS, YPOS,
                             rect.right-rect.left, 
                             rect.bottom-rect.top,
                             NULL,hMenu,instance,NULL);
@@ -547,7 +705,11 @@ int OpenDisplay( HANDLE instance, int mode )
     BitInfo->bmiHeader.biYPelsPerMeter = 0;
     BitInfo->bmiHeader.biClrImportant = 0;
     BitInfo->bmiHeader.biSizeImage = 0;
+#ifdef EIGHTBIT
     BitInfo->bmiHeader.biBitCount = 8;
+#else
+    BitInfo->bmiHeader.biBitCount = 32;
+#endif
     BitInfo->bmiHeader.biPlanes = 1;
 
     /* Initialise Palette! */
