@@ -1,10 +1,9 @@
-
 /***************************************************************************
- *                               RasMol 2.7.3                              *
+ *                              RasMol 2.7.6                               *
  *                                                                         *
  *                                 RasMol                                  *
  *                 Molecular Graphics Visualisation Tool                   *
- *                             6 February 2005                             *
+ *                              13 June 2009                               *
  *                                                                         *
  *                   Based on RasMol 2.6 by Roger Sayle                    *
  * Biomolecular Structures Group, Glaxo Wellcome Research & Development,   *
@@ -21,33 +20,56 @@
  *Philippe Valadon   RasTop 1.3     Aug 00     (C) Philippe Valadon 2000   *
  *                                                                         *
  *Herbert J.         RasMol 2.7.0   Mar 99     (C) Herbert J. Bernstein    * 
- *Bernstein          RasMol 2.7.1   Jun 99         1998-2001               *
+ *Bernstein          RasMol 2.7.1   Jun 99         1998-2008               *
  *                   RasMol 2.7.1.1 Jan 01                                 *
  *                   RasMol 2.7.2   Aug 00                                 *
  *                   RasMol 2.7.2.1 Apr 01                                 *
  *                   RasMol 2.7.2.1.1 Jan 04                               *
  *                   RasMol 2.7.3   Feb 05                                 *
+ *                   RasMol 2.7.3.1 Apr 06                                 *
+ *                   RasMol 2.7.4   Nov 07                                 *
+ *                   RasMol 2.7.4.1 Jan 08                                 *
+ *                   RasMol 2.7.4.2 Mar 08                                 *
+ *                   RasMol 2.7.5   May 09                                 *
  *                                                                         *
- *with RasMol 2.7.3 incorporating changes by Clarice Chigbo, Ricky Chachra,*
- *and Mamoru Yamanishi.  Work on RasMol 2.7.3 supported in part by         *
- *grants DBI-0203064, DBI-0315281 and EF-0312612 from the U.S. National    *
- *Science Foundation and grant DE-FG02-03ER63601 from the U.S. Department  *
- *of Energy.                                                               *
+ * RasMol 2.7.5 incorporates changes by T. Ikonen, G. McQuillan, N. Darakev*
+ * and L. Andrews (via the neartree package).  Work on RasMol 2.7.5        *
+ * supported in part by grant 1R15GM078077-01 from the National Institute  *
+ * of General Medical Sciences (NIGMS), U.S. National Institutes of Health *
+ * and by grant ER63601-1021466-0009501 from the Office of Biological &    *
+ * Environmental Research (BER), Office of Science, U. S. Department of    *
+ * Energy.  RasMol 2.7.4 incorporated  changes by G. Todorov, Nan Jia,     *
+ * N. Darakev, P. Kamburov, G. McQuillan, and J. Jemilawon. Work on RasMol *
+ * 2.7.4 supported in part by grant 1R15GM078077-01 from the NIGMS/NIH and *
+ * grant ER63601-1021466-0009501 from BER/DOE.  RasMol 2.7.3 incorporates  *
+ * changes by Clarice Chigbo, Ricky Chachra, and Mamoru Yamanishi.  Work   *
+ * on RasMol 2.7.3 supported in part by grants DBI-0203064, DBI-0315281    *
+ * and EF-0312612 from the U.S. National Science Foundation and grant      *
+ * DE-FG02-03ER63601 from BER/DOE. The content is solely the responsibility*
+ * of the authors and does not necessarily represent the official views of *
+ * the funding organizations.                                              *
+ *                                                                         *
+ * The code for use of RasMol under GTK in RasMol 2.7.4.2 and 2.7.5 was    *
+ * written by Teemu Ikonen.                                                *
  *                                                                         *
  *                    and Incorporating Translations by                    *
- *  Author                               Item                      Language*
+ *  Author                               Item                     Language *
  *  Isabel Servan Martinez,                                                *
- *  Jose Miguel Fernandez Fernandez      2.6   Manual              Spanish *
- *  Jose Miguel Fernandez Fernandez      2.7.1 Manual              Spanish *
- *  Fernando Gabriel Ranea               2.7.1 menus and messages  Spanish *
- *  Jean-Pierre Demailly                 2.7.1 menus and messages  French  *
+ *  Jose Miguel Fernandez Fernandez      2.6   Manual             Spanish  *
+ *  Jose Miguel Fernandez Fernandez      2.7.1 Manual             Spanish  *
+ *  Fernando Gabriel Ranea               2.7.1 menus and messages Spanish  *
+ *  Jean-Pierre Demailly                 2.7.1 menus and messages French   *
  *  Giuseppe Martini, Giovanni Paolella, 2.7.1 menus and messages          *
- *  A. Davassi, M. Masullo, C. Liotto    2.7.1 help file           Italian *
+ *  A. Davassi, M. Masullo, C. Liotto    2.7.1 help file          Italian  *
+ *  G. Pozhvanov                         2.7.3 menus and messages Russian  *
+ *  G. Todorov                           2.7.3 menus and messages Bulgarian*
+ *  Nan Jia, G. Todorov                  2.7.3 menus and messages Chinese  *
+ *  Mamoru Yamanishi, Katajima Hajime    2.7.3 menus and messages Japanese *
  *                                                                         *
  *                             This Release by                             *
- * Herbert J. Bernstein, Bernstein + Sons, P.O. Box 177, Bellport, NY, USA *
+ * Herbert J. Bernstein, Bernstein + Sons, 5 Brewster Ln, Bellport, NY, USA*
  *                       yaya@bernstein-plus-sons.com                      *
- *               Copyright(C) Herbert J. Bernstein 1998-2005               *
+ *               Copyright(C) Herbert J. Bernstein 1998-2008               *
  *                                                                         *
  *                READ THE FILE NOTICE FOR RASMOL LICENSES                 *
  *Please read the file NOTICE for important notices which apply to this    *
@@ -64,11 +86,14 @@
 /* #define IBMPC        */
 /* #define MSWIN        */
 /* #define APPLEMAC     */
-#define X11WIN
+/* #define X11WIN       */    /* X11WIN or GTKWIN defined in Imakefile */
 #define UNIX
+#define STDINT
 
 /* #define DIALBOX      */
+#ifndef GTKWIN
 #define SOCKETS
+#endif
 #define TERMIOS
 #define PROFILE
 #define MITSHM
@@ -89,12 +114,26 @@
 #endif
 
 /* #define XPROCARCH    */
+#define USE_UNAME
 
+#define USE_CBFLIB
+
+#ifndef CNEARTREE_FAR
+#define CNEARTREE_FAR 
+#endif
+
+#ifndef VECTOR_FAR
+#define VECTOR_FAR 
+#endif
 
 /*========================*/
 /*  Default User Options! */
 /*========================*/
 
+#ifdef STDINT
+#include <stdint.h>
+#endif
+
 #ifdef IBMPC
 #undef THIRTYTWOBIT
 #undef SIXTEENBIT
@@ -152,9 +191,9 @@
 /*==============================*/
 
 #define MAIN_COPYRIGHT "Copyright (C) Roger Sayle 1992-1999"
-#define VERSION "2.7.3.1"
-#define VER_COPYRIGHT "Copyright (C) Herbert J. Bernstein 1998-2006"
-#define VER_DATE "April 2006"
+#define VERSION "2.7.6.0"
+#define VER_COPYRIGHT "Copyright (C) Herbert J. Bernstein 1998-2011"
+#define VER_DATE "May 2011"
 
 #ifndef True
 #define True  1
@@ -168,8 +207,12 @@
 
 typedef double Real;
 #ifndef APPLEMAC
+#ifdef STDINT
+typedef uint8_t Byte;
+#else
 typedef unsigned char Byte;
 #endif
+#endif
 
 #ifdef __STDC__
 typedef signed char Char;
@@ -178,14 +221,33 @@ typedef char Char;
 #endif
 
 #ifdef _LONGLONG
+  #ifdef STDINT
+  typedef uint32_t Card;
+  #else
 typedef unsigned int Card;
-typedef int Long;
+  #endif
+  typedef long Long;
 #else
+  #ifdef STDINT
+  typedef uint32_t Card;
+  #else
 typedef unsigned long Card;
+  #endif
 typedef long Long;
 #endif
 
+#ifdef STDINT
 #ifdef EIGHTBIT
+  typedef uint8_t Pixel;
+  #else
+  #ifdef THIRTYTWOBIT
+  typedef int32_t Pixel;
+  #else
+  typedef int16_t Pixel;
+  #endif
+  #endif
+#else
+  #ifdef EIGHTBIT
 typedef unsigned char Pixel;
 #else
 #ifdef THIRTYTWOBIT
@@ -194,6 +256,7 @@ typedef Long Pixel;
 typedef short Pixel;
 #endif
 #endif
+#endif
 
 
 #if defined(__sgi)
@@ -230,10 +293,16 @@ typedef short Pixel;
 #define _fmemset   memset
 #define __huge
 #define __far
+#else
+#ifdef USE_CBFLIB
+#define _fmalloc   halloc
+#define _ffree     hfree
+#define __far      __huge
+#endif
 #endif
 
 
-#define ItemCount       8
+#define ItemCount       9
 #define AdvPickAtom     0
 #define AdvPickNumber   1
 #define AdvSelectCount  2
@@ -242,14 +311,18 @@ typedef short Pixel;
 #define AdvClass        5
 #define AdvImage        6
 #define AdvPickCoord    7
+#define AdvDetail       8
 
 
+#define MSG_MAX 256
 void WriteChar( int );
 void WriteString( char* );
+void WriteMsg( char* );
 void RasMolFatalExit( char* );
 void AdviseUpdate( int );
 void RefreshScreen( void );
 void RasMolExit( void );
+void HandleMenu( int hand );
 
 #ifdef APPLEMAC
 #include "rasmac.h"
