@@ -1,10 +1,9 @@
-
 /***************************************************************************
- *                               RasMol 2.7.3                              *
+ *                              RasMol 2.7.5                               *
  *                                                                         *
  *                                 RasMol                                  *
  *                 Molecular Graphics Visualisation Tool                   *
- *                             6 February 2005                             *
+ *                              13 June 2009                               *
  *                                                                         *
  *                   Based on RasMol 2.6 by Roger Sayle                    *
  * Biomolecular Structures Group, Glaxo Wellcome Research & Development,   *
@@ -21,33 +20,56 @@
  *Philippe Valadon   RasTop 1.3     Aug 00     (C) Philippe Valadon 2000   *
  *                                                                         *
  *Herbert J.         RasMol 2.7.0   Mar 99     (C) Herbert J. Bernstein    * 
- *Bernstein          RasMol 2.7.1   Jun 99         1998-2001               *
+ *Bernstein          RasMol 2.7.1   Jun 99         1998-2008               *
  *                   RasMol 2.7.1.1 Jan 01                                 *
  *                   RasMol 2.7.2   Aug 00                                 *
  *                   RasMol 2.7.2.1 Apr 01                                 *
  *                   RasMol 2.7.2.1.1 Jan 04                               *
  *                   RasMol 2.7.3   Feb 05                                 *
+ *                   RasMol 2.7.3.1 Apr 06                                 *
+ *                   RasMol 2.7.4   Nov 07                                 *
+ *                   RasMol 2.7.4.1 Jan 08                                 *
+ *                   RasMol 2.7.4.2 Mar 08                                 *
+ *                   RasMol 2.7.5   May 09                                 *
  *                                                                         *
- *with RasMol 2.7.3 incorporating changes by Clarice Chigbo, Ricky Chachra,*
- *and Mamoru Yamanishi.  Work on RasMol 2.7.3 supported in part by         *
- *grants DBI-0203064, DBI-0315281 and EF-0312612 from the U.S. National    *
- *Science Foundation and grant DE-FG02-03ER63601 from the U.S. Department  *
- *of Energy.                                                               *
+ * RasMol 2.7.5 incorporates changes by T. Ikonen, G. McQuillan, N. Darakev*
+ * and L. Andrews (via the neartree package).  Work on RasMol 2.7.5        *
+ * supported in part by grant 1R15GM078077-01 from the National Institute  *
+ * of General Medical Sciences (NIGMS), U.S. National Institutes of Health *
+ * and by grant ER63601-1021466-0009501 from the Office of Biological &    *
+ * Environmental Research (BER), Office of Science, U. S. Department of    *
+ * Energy.  RasMol 2.7.4 incorporated  changes by G. Todorov, Nan Jia,     *
+ * N. Darakev, P. Kamburov, G. McQuillan, and J. Jemilawon. Work on RasMol *
+ * 2.7.4 supported in part by grant 1R15GM078077-01 from the NIGMS/NIH and *
+ * grant ER63601-1021466-0009501 from BER/DOE.  RasMol 2.7.3 incorporates  *
+ * changes by Clarice Chigbo, Ricky Chachra, and Mamoru Yamanishi.  Work   *
+ * on RasMol 2.7.3 supported in part by grants DBI-0203064, DBI-0315281    *
+ * and EF-0312612 from the U.S. National Science Foundation and grant      *
+ * DE-FG02-03ER63601 from BER/DOE. The content is solely the responsibility*
+ * of the authors and does not necessarily represent the official views of *
+ * the funding organizations.                                              *
+ *                                                                         *
+ * The code for use of RasMol under GTK in RasMol 2.7.4.2 and 2.7.5 was    *
+ * written by Teemu Ikonen.                                                *
  *                                                                         *
  *                    and Incorporating Translations by                    *
- *  Author                               Item                      Language*
+ *  Author                               Item                     Language *
  *  Isabel Servan Martinez,                                                *
- *  Jose Miguel Fernandez Fernandez      2.6   Manual              Spanish *
- *  Jose Miguel Fernandez Fernandez      2.7.1 Manual              Spanish *
- *  Fernando Gabriel Ranea               2.7.1 menus and messages  Spanish *
- *  Jean-Pierre Demailly                 2.7.1 menus and messages  French  *
+ *  Jose Miguel Fernandez Fernandez      2.6   Manual             Spanish  *
+ *  Jose Miguel Fernandez Fernandez      2.7.1 Manual             Spanish  *
+ *  Fernando Gabriel Ranea               2.7.1 menus and messages Spanish  *
+ *  Jean-Pierre Demailly                 2.7.1 menus and messages French   *
  *  Giuseppe Martini, Giovanni Paolella, 2.7.1 menus and messages          *
- *  A. Davassi, M. Masullo, C. Liotto    2.7.1 help file           Italian *
+ *  A. Davassi, M. Masullo, C. Liotto    2.7.1 help file          Italian  *
+ *  G. Pozhvanov                         2.7.3 menus and messages Russian  *
+ *  G. Todorov                           2.7.3 menus and messages Bulgarian*
+ *  Nan Jia, G. Todorov                  2.7.3 menus and messages Chinese  *
+ *  Mamoru Yamanishi, Katajima Hajime    2.7.3 menus and messages Japanese *
  *                                                                         *
  *                             This Release by                             *
- * Herbert J. Bernstein, Bernstein + Sons, P.O. Box 177, Bellport, NY, USA *
+ * Herbert J. Bernstein, Bernstein + Sons, 5 Brewster Ln, Bellport, NY, USA*
  *                       yaya@bernstein-plus-sons.com                      *
- *               Copyright(C) Herbert J. Bernstein 1998-2005               *
+ *               Copyright(C) Herbert J. Bernstein 1998-2008               *
  *                                                                         *
  *                READ THE FILE NOTICE FOR RASMOL LICENSES                 *
  *Please read the file NOTICE for important notices which apply to this    *
@@ -115,8 +137,6 @@ static struct termios IntrTerm;
 #endif
 
 
-static int InitialWide;
-static int InitialHigh;
 
 static char *FileNamePtr;
 static char *ScriptNamePtr;
@@ -124,6 +144,12 @@ static int FileFormat;
 static int ProfCount;
 
 
+void WriteMsg( char *ptr )
+{
+    WriteString(ptr);
+    WriteChar ('\n');
+}
+
 
 void WriteChar( int ch )
 {   putc(ch,OutFp);
@@ -394,7 +420,7 @@ void EndWait( void )
 }
 
 
-int OpenDisplay( int x, int y )
+int OpenDisplay( void )
 {
     register int i;
 
@@ -422,23 +448,42 @@ void AdviseUpdate( int item )
 
 void RefreshScreen( void )
 {
+    int ReDrawFlagSave;
     if( !UseSlabPlane )
     {   ReDrawFlag &= ~RFTransZ|RFSlab;
     } else ReDrawFlag &= ~RFTransZ;
-
+    
+    ReDrawFlagSave = ReDrawFlag;
     if( ReDrawFlag )
     {   if( ReDrawFlag & RFReSize )
             ReSizeScreen();
 
         if( ReDrawFlag & RFColour )
             DefineColourMap();
-
+        
+        NextReDrawFlag = 0;
         if( Database )
         {   if( ReDrawFlag & RFApply ) 
                 ApplyTransform();
             DrawFrame();
         }
-        ReDrawFlag = 0;
+        if ((ReDrawFlagSave & RFApply) && record_on[0] && !RecordPause ) {
+	      WriteMovieFrame();
+	      record_frame[0]++;
+	      record_frame[1] = 0;
+	    } else if ((ReDrawFlagSave & RFAppear) && record_on[1] && !RecordPause) {
+	      WriteMovieFrame();
+	      record_frame[0]++;
+	      record_frame[1]++;
+	      if ((double)(record_frame[1]) <= record_fps*record_dwell) {
+	        NextReDrawFlag |= RFRefresh;
+	      } else {
+	      	NextReDrawFlag = 0;
+	      	record_frame[1] = 0;
+	      }
+	    }
+    }
+
     }
 }
 
@@ -475,8 +520,7 @@ static void InitDefaultValues( void )
 
     FileNamePtr = NULL;
     ScriptNamePtr = NULL;
-    InitialWide = DefaultWide;
-    InitialHigh = DefaultHigh;
+    InitWidth = InitHeight = InitXPos = InitYPos = 0;
     ProfCount = 0;
 
     FileFormat = FormatPDB;
@@ -543,15 +587,18 @@ static void ProcessOptions( int argc, char *argv[] )
             } else if( !strcmp(ptr,"width") ||
                        !strcmp(ptr,"wide") )
             {   if( i == argc-1 ) DisplayUsage();
-                InitialWide = atoi(argv[++i]);
-                if( InitialWide < 48 )
-                    InitialWide = 48;
+                InitWidth = atoi(argv[++i]);
+                if( InitWidth < 48 )
+                    InitWidth = 48;
+                else if( (j = InitWidth%4) )
+                    InitWidth += 4-j;
+
             } else if( !strcmp(ptr,"height") ||
                        !strcmp(ptr,"high") )
             {   if( i == argc-1 ) DisplayUsage();
-                InitialHigh = atoi(argv[++i]);
-                if( InitialHigh < 48 )
-                    InitialHigh = 48;
+                InitHeight = atoi(argv[++i]);
+                if( InitHeight < 48 )
+                    InitHeight = 48;
 
             } else if( !strcmp(ptr,"sybyl") )
             {   FileFormat = FormatMol2;
@@ -582,6 +629,29 @@ static void ProcessOptions( int argc, char *argv[] )
 }
 
 
+
+/* dummy ShowInterpNames */
+
+int ShowInterpNames ( void )
+{
+    return False;
+}
+
+/* dummy CheckInterpName */
+
+
+int CheckInterpName( char __huge *name, unsigned long __huge *interpid) {
+    return False;
+}
+
+/* dummy SendInterpCommand */
+
+int SendInterpCommand( char __huge *name, unsigned long interpid,
+                       char __huge *command){
+    return False;
+}
+
+
 int main( int argc, char *argv[] )
 {
     register FILE *fp;
@@ -600,7 +670,7 @@ int main( int argc, char *argv[] )
     ReDrawFlag = 0;
     
     setbuf(OutFp,(char *)NULL);
-    OpenDisplay(InitialWide,InitialHigh);
+    OpenDisplay();
     InitTerminal();
 
 #ifdef UNIX
@@ -655,6 +725,7 @@ int main( int argc, char *argv[] )
         SetRibbonCartoons();
         EnableWireframe(WireFlag,0,0);
         RefreshScreen();
+        ReDrawFlag = NextReDrawFlag;
 
         /* Avoid Pending Events */
         ProfileExecution();
@@ -671,6 +742,7 @@ int main( int argc, char *argv[] )
         if( done )
         {   DefaultRepresentation();
             RefreshScreen();
+            ReDrawFlag = NextReDrawFlag;
         }
     }
 
@@ -698,6 +770,7 @@ int main( int argc, char *argv[] )
             {   RefreshScreen();
                 if( !CommandActive )
                     ResetCommandLine(0);
+                ReDrawFlag = NextReDrawFlag;
             } else done = True;
         }
     }
