@@ -1,10 +1,9 @@
-
 /***************************************************************************
- *                               RasMol 2.7.3                              *
+ *                              RasMol 2.7.5                               *
  *                                                                         *
  *                                 RasMol                                  *
  *                 Molecular Graphics Visualisation Tool                   *
- *                             6 February 2005                             *
+ *                              13 June 2009                               *
  *                                                                         *
  *                   Based on RasMol 2.6 by Roger Sayle                    *
  * Biomolecular Structures Group, Glaxo Wellcome Research & Development,   *
@@ -21,40 +20,109 @@
  *Philippe Valadon   RasTop 1.3     Aug 00     (C) Philippe Valadon 2000   *
  *                                                                         *
  *Herbert J.         RasMol 2.7.0   Mar 99     (C) Herbert J. Bernstein    * 
- *Bernstein          RasMol 2.7.1   Jun 99         1998-2001               *
+ *Bernstein          RasMol 2.7.1   Jun 99         1998-2008               *
  *                   RasMol 2.7.1.1 Jan 01                                 *
  *                   RasMol 2.7.2   Aug 00                                 *
  *                   RasMol 2.7.2.1 Apr 01                                 *
  *                   RasMol 2.7.2.1.1 Jan 04                               *
  *                   RasMol 2.7.3   Feb 05                                 *
+ *                   RasMol 2.7.3.1 Apr 06                                 *
+ *                   RasMol 2.7.4   Nov 07                                 *
+ *                   RasMol 2.7.4.1 Jan 08                                 *
+ *                   RasMol 2.7.4.2 Mar 08                                 *
+ *                   RasMol 2.7.5   May 09                                 *
  *                                                                         *
- *with RasMol 2.7.3 incorporating changes by Clarice Chigbo, Ricky Chachra,*
- *and Mamoru Yamanishi.  Work on RasMol 2.7.3 supported in part by         *
- *grants DBI-0203064, DBI-0315281 and EF-0312612 from the U.S. National    *
- *Science Foundation and grant DE-FG02-03ER63601 from the U.S. Department  *
- *of Energy.                                                               *
+ * RasMol 2.7.5 incorporates changes by T. Ikonen, G. McQuillan, N. Darakev*
+ * and L. Andrews (via the neartree package).  Work on RasMol 2.7.5        *
+ * supported in part by grant 1R15GM078077-01 from the National Institute  *
+ * of General Medical Sciences (NIGMS), U.S. National Institutes of Health *
+ * and by grant ER63601-1021466-0009501 from the Office of Biological &    *
+ * Environmental Research (BER), Office of Science, U. S. Department of    *
+ * Energy.  RasMol 2.7.4 incorporated  changes by G. Todorov, Nan Jia,     *
+ * N. Darakev, P. Kamburov, G. McQuillan, and J. Jemilawon. Work on RasMol *
+ * 2.7.4 supported in part by grant 1R15GM078077-01 from the NIGMS/NIH and *
+ * grant ER63601-1021466-0009501 from BER/DOE.  RasMol 2.7.3 incorporates  *
+ * changes by Clarice Chigbo, Ricky Chachra, and Mamoru Yamanishi.  Work   *
+ * on RasMol 2.7.3 supported in part by grants DBI-0203064, DBI-0315281    *
+ * and EF-0312612 from the U.S. National Science Foundation and grant      *
+ * DE-FG02-03ER63601 from BER/DOE. The content is solely the responsibility*
+ * of the authors and does not necessarily represent the official views of *
+ * the funding organizations.                                              *
+ *                                                                         *
+ * The code for use of RasMol under GTK in RasMol 2.7.4.2 and 2.7.5 was    *
+ * written by Teemu Ikonen.                                                *
  *                                                                         *
  *                    and Incorporating Translations by                    *
- *  Author                               Item                      Language*
+ *  Author                               Item                     Language *
  *  Isabel Servan Martinez,                                                *
- *  Jose Miguel Fernandez Fernandez      2.6   Manual              Spanish *
- *  Jose Miguel Fernandez Fernandez      2.7.1 Manual              Spanish *
- *  Fernando Gabriel Ranea               2.7.1 menus and messages  Spanish *
- *  Jean-Pierre Demailly                 2.7.1 menus and messages  French  *
+ *  Jose Miguel Fernandez Fernandez      2.6   Manual             Spanish  *
+ *  Jose Miguel Fernandez Fernandez      2.7.1 Manual             Spanish  *
+ *  Fernando Gabriel Ranea               2.7.1 menus and messages Spanish  *
+ *  Jean-Pierre Demailly                 2.7.1 menus and messages French   *
  *  Giuseppe Martini, Giovanni Paolella, 2.7.1 menus and messages          *
- *  A. Davassi, M. Masullo, C. Liotto    2.7.1 help file           Italian *
+ *  A. Davassi, M. Masullo, C. Liotto    2.7.1 help file          Italian  *
+ *  G. Pozhvanov                         2.7.3 menus and messages Russian  *
+ *  G. Todorov                           2.7.3 menus and messages Bulgarian*
+ *  Nan Jia, G. Todorov                  2.7.3 menus and messages Chinese  *
+ *  Mamoru Yamanishi, Katajima Hajime    2.7.3 menus and messages Japanese *
  *                                                                         *
  *                             This Release by                             *
- * Herbert J. Bernstein, Bernstein + Sons, P.O. Box 177, Bellport, NY, USA *
+ * Herbert J. Bernstein, Bernstein + Sons, 5 Brewster Ln, Bellport, NY, USA*
  *                       yaya@bernstein-plus-sons.com                      *
- *               Copyright(C) Herbert J. Bernstein 1998-2005               *
+ *               Copyright(C) Herbert J. Bernstein 1998-2008               *
  *                                                                         *
  *                READ THE FILE NOTICE FOR RASMOL LICENSES                 *
  *Please read the file NOTICE for important notices which apply to this    *
  *package and for license terms (GPL or RASLIC).                           *
  ***************************************************************************/
 /* transfor.h
- $Log: transfor.h,v $
+ $Log$
+ Revision 1.7  2008/03/22 18:42:55  yaya
+ Post release cleanup and credit to Ikonen in file headers. -- HJB
+
+ Revision 1.6  2008/03/17 03:01:32  yaya
+ Update to agree with 2.7.4.2 release and T. Ikonen GTK mods -- HJB
+
+ Revision 1.3  2008/03/17 01:32:41  yaya
+ Add gtk mods by tpikonen, and intergate with 2.7.4.2 mods -- HJB
+
+ Revision 1.5  2008/03/16 22:25:22  yaya
+ Align comments with production version; Update rasmol_install and
+ rasmol_run shell scripts for Japanese and Chinese; Align logic for
+ positioning and sizing initial window with windows version -- HJB
+
+ Revision 1.2  2008/01/28 03:29:38  yaya
+ Update CVS to RasMol_2.7.4.1 -- HJB
+
+ Revision 1.4  2007/11/19 03:28:40  yaya
+ Update to credits for 2.7.4 in manual and headers
+ Mask code added -- HJB
+
+ Revision 1.3  2007/11/13 03:22:17  yaya
+ Changes to support map selectors.  Needs more work. -- HJB
+
+ Revision 1.2  2007/09/13 20:05:07  yaya
+ RasWin 2.7.4 PreRelease 1 -- HJB
+
+ Revision 1.1.1.1  2007/03/01 01:16:32  todorovg
+ Chinese working versio from rasmol_ru initial import
+
+ Revision 1.3  2006/11/01 03:23:51  yaya
+ Update NSIS windows installer for more script types and to fix
+ misplaced script instructions for data files; add document and
+ script icons directly in raswin.exe; add credit line to
+ G. A. Pozhvanov in comments for Russian translations. -- HJB
+
+ Revision 1.2  2006/09/17 10:53:56  yaya
+ Clean up headers and start on code for X11 -- HJB
+
+ Revision 1.1.1.1  2006/09/16 18:46:02  yaya
+ Start of RasMol Russian Translation Project based on translations
+ by Gregory A. Pozhvanov of Saint Petersburg State University -- HJB
+
+ Revision 1.1.1.1  2006/06/19 22:05:14  todorovg
+ Initial Rasmol 2.7.3 Import
+
  Revision 1.1  2004/05/07 19:46:16  yaya
  Initial revision
 
@@ -90,6 +158,8 @@
 
  */
 
+#include "CVector_3D.h"
+
 #define GroupAttr       0x00
 #define ChainAttr       0x01
 #define TempAttr	    0x02
@@ -170,6 +240,16 @@ typedef struct {
 #define Colour2Shade(x)  ((int)((x)-FirstCol)/ColourDepth)
 #define Shade2Colour(x)  ((x)*ColourDepth+FirstCol)
 
+#define ALIGN_KABSCH       1
+#define ALIGN_LOCAL        2
+#define ALIGN_NONE         1
+#define ALIGN_ANGLE        2
+#define ALIGN_DISTANCE     3
+#define ALIGN_ANGLE_SUM    4
+#define ALIGN_DISTANCE_SUM 5
+#define ALIGN_STRUCTURE    1
+#define ALIGN_SUBSTRUCTURE 2
+
 
 #ifdef TRANSFORM
 ShadeDesc Shade[LastShade];
@@ -209,6 +289,7 @@ int DrawBonds,MaxBondRadius;
 int DrawStars;
 int DrawSurf;
 int DrawRibbon;
+int DrawField,MaxVectorField;
 int ZoneBoth;
 int ModelInclude;
 
@@ -216,10 +297,13 @@ int ScaleCount;
 ShadeRef ScaleRef[LastShade];
 int AltlColours[AltlDepth];
 
-Real LastRX,LastRY,LastRZ;
-Real LastTX,LastTY,LastTZ;
 Real Zoom;
 
+double record_fps, play_fps, record_aps, record_dwell;
+int record_on[2];
+size_t record_frame[2], play_frame[2];
+
+
 
 #else
 extern ShadeDesc Shade[LastShade];
@@ -260,6 +344,7 @@ extern int DrawBonds,MaxBondRadius;
 extern int DrawStars;
 extern int DrawSurf;
 extern int DrawRibbon;
+extern int DrawField,MaxVectorField;
 extern int ZoneBoth;
 extern int ModelInclude;
 
@@ -270,17 +355,24 @@ extern int AltlColours[AltlDepth];
 extern ShadeDesc Shade[LastShade];
 extern Real RotX[3],RotY[3],RotZ[3];
 
-extern Real LastRX,LastRY,LastRZ;
-extern Real LastTX,LastTY,LastTZ;
 extern Real Zoom;
 
+
+extern double record_fps, play_fps, record_aps, record_dwell;
+extern int record_on[2];
+extern size_t record_frame[2], play_frame[2];
+
 #endif
 
+void SetOneFieldValue(long field[4], RAtom __far *aptr, int wait);
+void SetFieldValue(long field[4]);
+void ScaleFieldValue(long fscale);
 
 void SetRadiusValue( int, int  );
 void SetRadiusTemperature( int );
 void SetVanWaalRadius( int );
 void DisableSpacefill( void );
+void DisableField( void );
 void SetHBondStatus( int, int, int, int );
 void SetRibbonStatus( int, int, int );
 void SetRibbonCartoons( void );
@@ -309,12 +401,14 @@ int DefineShade( int, int, int );
 void DefineColourMap( void );
 void ResetColourMap( void );
 
+void ColourFieldNone( void );
 void ColourBackNone( void );
 void ColourBondNone( void );
 void ColourHBondType( void );
 void ColourHBondNone( int );
 void ColourRibbonNone( int );
 void ColourMonitNone( void );
+void ColourFieldAttrib( int, int, int );
 void ColourBackAttrib( int, int, int );
 void ColourBondAttrib( int, int, int );
 void ColourHBondAttrib( int, int, int, int );
@@ -322,6 +416,9 @@ void ColourRibbonAttrib( int, int, int, int );
 void ColourMonitAttrib( int, int, int );
 void ColourDotsAttrib( int, int, int );
 void ColourDotsPotential( void );
+void ColourPointAttrib( int, int, int, int );
+void ColourPointPotential( int );
+void ColourPointAtom( int );
 void MonoColourAttrib( int, int, int );
 void ScaleColourAttrib( int );
 void CPKColourAttrib( void );
@@ -348,3 +445,15 @@ void CentreTransform( int, int, int, int );
 void ResetTransform( void );
 
 void SetLutEntry( int, int, int, int );
+void TestKabsch( const CVectorHandle /*CV3Vector */ v1,
+                 const CVectorHandle /*CV3Vector */ v2,
+                 CQRQuaternionHandle q,
+                 double * rmsd );
+void GatherSelected(CVectorHandle /* RAtom * */ selAtoms, CVectorHandle /* Group * */ selGroups  );
+int AlignToMolecule(int molnum, double * rmsd, 
+                    CQRQuaternionHandle qRotToMolecule, 
+                    CV3VectorHandle vTransToMolecule,
+                    int seqrange, double mindist, 
+                    double maxdist, int kabsch_local,
+                    int none_ang_dist, int xlatecen,
+                    int findsubstructure, char * scripts);
\ No newline at end of file
